import axios from "axios";
import {Resp} from "@util/Resp";
import {Builder, Parser} from "xml2js";
import {Logger} from "@util/Logger";

let xml2js = require('xml2js');

export interface IMpOpenIdInfo {
    session_key: string;
    open_id: string;
    app_type: number;
}

export interface IMpUserInfo {
    nickname: string;
    avatarUrl: string;
    unionId?: string;
}

export interface IMobileInfo {
    mobile: string;
}

export abstract class MpPlatformBase {
    // protected db: Database;
    protected xmlBuilder: Builder;
    protected xmlParser: Parser;
    protected platform: number;

    protected constructor(platform: number) {
        this.platform = platform;
        // this.db = Database.getInstance('mpPlatform')
        this.xmlBuilder = new xml2js.Builder({cdata: true});
        this.xmlParser = new xml2js.Parser({explicitArray: false, ignoreAttrs: true});
    }

    get type(): number {
        return this.platform;
    }

    abstract init(): void;

    abstract getOpenId(appId: string, code: string): Promise<IMpOpenIdInfo>;


    abstract createSign(appId: string, timestamp: string, nonce: string, prepayId: string, privateKey: string): string;
    abstract decryptUserInfo(key: string, encryptInfo: any): IMpUserInfo;
    abstract decryptMobile(key: string, encryptInfo: any): IMobileInfo;

    abstract createPrepayReqInfo(orderId: string, appId: string, prepayId: string, privateKey: string): any;

    abstract unifiedorder(appId: string, notifyHost: string, openId: string, total: number, orderId: string, attach?: string): Promise<any>;
    abstract refunds(appId: string, notifyHost: string, openId: string, total: number, refund: number, orderId: string): Promise<any>;
    abstract queryRefund(appId: string, out_refund_no: string): Promise<any>;
    abstract queryUnifiedorder(appId: string, out_trade_no: string): Promise<any>;

    protected apiGet(url: string, headers?: any): Promise<unknown> {
        return new Promise<unknown>(async (resolve, reject) => {
            try {
                let options: any = {};
                if (headers) options.headers = headers;
                let axiosResponse = await axios.get(url, options);
                if (axiosResponse.status !== 200) {
                    Logger.trace(axiosResponse);
                    return reject(Resp.gen_err(Resp.MpPlatformFail, `status code: ${axiosResponse.status}`));
                }
                resolve(axiosResponse.data);
            } catch (e) {
                Logger.error(e);
                reject(Resp.gen_err(Resp.MpPlatformFail));
            }
        })
    }

    protected apiPost(url: string, data: any, headers?: any): Promise<unknown> {
        return new Promise<unknown>(async (resolve, reject) => {
            try {
                // let headers = {};
                // let req;
                // if (xml) {
                //     headers = {'Content-Type': 'text/xml'};
                //     req = this.xmlBuilder.buildObject(data);
                // } else {
                //     req = data;
                // }
                let options: any = {};
                if (headers) options.headers = headers;

                let axiosResponse = await axios.post(url, data, options);
                let res;
                // if (xml) {
                //     res = await this.xmlParser.parseStringPromise(axiosResponse.data);
                //     res = res.xml;
                // } else {
                res = axiosResponse.data;
                // }
                resolve(res);
            } catch (e) {
                Logger.error(e);
                reject(Resp.gen_err(Resp.MpPlatformFail));
            }
        })
    }
}
