import {Platform} from "@core/Defined";
import {MpPlatformBase} from "@classes/MpPlatformBase";
import {WxPlatform} from "@classes/WxPlatform";

export type PlatformType = 'wx' | 'alipay';


export class MpPlatformFactory {
    static instanceMap: Map<PlatformType, MpPlatformBase> = new Map<PlatformType, MpPlatformBase>();

   static  async initInstance(platform: PlatformType) {
        let instance = MpPlatformFactory.instanceMap.get(platform);
        if (!instance) {
            switch (platform) {
                case "wx":
                    let wx: MpPlatformBase = new WxPlatform(Platform.wx);
                    await wx.init();
                    MpPlatformFactory.instanceMap.set('wx', wx);
                    break;
            }
        }
    }

    static getInstance(platform: PlatformType): MpPlatformBase {
        let instance = MpPlatformFactory.instanceMap.get(platform);
        if (!instance) {
            throw new Error(`mini program platform ${platform} should be init.`);
        }
        return instance;
    }
}
