import {Model, DataTypes} from "sequelize";

export class AcsApplication extends Model {
    declare app_id: string;
    declare app_key: string;
    declare name: string;
    declare app_type: number;
    declare auth_type: number;
    declare private_key: string;
    declare public_key: string;
    declare status: number;
    declare memo: string;
    declare pay_key: string;
    declare mch_id: string;//商户号
    declare api_cert_serial_no: string;

    static table_name = 'tb_acs_application';
    static attributes = {
        app_id: {
            type: DataTypes.STRING,
            primaryKey: true,
            comment: "应用或服务的app id"
        },
        app_key: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: "app key"
        },
        name: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: "应用或服务名称"
        },
        app_type: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: "类型，0=内部微服务 1=微信小程序，2=支付宝小程序，3=web客户端，4=设备端，5=第三方平台"
        },
        auth_type: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: "认证方式：1=仅账号密码 2=账号密码+签名 3=仅签名"
        },
        private_key: {
            type: DataTypes.TEXT,
            comment: "pem格式私钥证书"
        },
        public_key: {
            type: DataTypes.TEXT,
            comment: "pem格式公钥证书"
        },
        status: {
            type: DataTypes.INTEGER,
            allowNull: false,
            defaultValue: 1,
            comment: "应用状态，1=正常，2=锁定"
        },
        memo: {
            type: DataTypes.TEXT,
            defaultValue: "",
            comment: "备注"
        },
        pay_key: {
            type: DataTypes.STRING,
            comment: '商户平台设置的密钥key'
        },
        mch_id: {
            type: DataTypes.STRING,
            comment: '商户号'
        },
        api_cert_serial_no: {
            type: DataTypes.STRING,
            comment: 'api证书序号'
        },
    }

    static indexes = [
        {fields: ['app_id']},
    ]
    static init_sqls = [
        `insert into tb_acs_application (app_id, app_key, name, app_type, auth_type, status) values('f2741721-1c07-430e-9f01-5529692340f9', 'UA3u7eX9BtHNtWitnbvbWJxQK6RepbqZ', 'web客户端', 3, 1, 1) ON CONFLICT DO NOTHING`,
    ];
}
