import {Model, DataTypes} from "sequelize";

export class AcsDomain extends Model {
    declare id: number;
    declare name: string;
    declare pid: number;
    declare path: string;
    declare memo: string;
    declare tag: string;

    static table_name = 'tb_acs_domain';
    static attributes = {
        id: {
            type: DataTypes.INTEGER,
            autoIncrement: true,
            primaryKey: true,
            comment: '自增量id'
        },
        name: {
            type: DataTypes.STRING,
            comment: '域名称'
        },
        pid: {
            type: DataTypes.INTEGER,
            comment: '父域id',
            allowNull: true,
            references: {
                model: AcsDomain,
                key: 'id'
            },
        },
        path: {
            type: DataTypes.STRING,
            comment: '树ltree路径'
        },
        memo: {
            type: DataTypes.STRING,
            allowNull: true,
            defaultValue: '',
            comment: '备注'
        },
        tag: {
            type: DataTypes.STRING,
            comment:'标记'
        },
        category: {
            type: DataTypes.STRING,
            comment: '域类别'
        }
    }

    static indexes = [
        // {fields: ['pid', 'name'], unique: true},
    ]

    static init_sqls = [
        `alter table tb_acs_domain alter column path type ltree using path::ltree; `,
        `insert into tb_acs_domain (id, name, pid, path) values(1, '所有', null, text2ltree('1')) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(2, '系统运维域', 1, text2ltree('1.2'), 'acs', null) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(3, '业务运营域', 1, text2ltree('1.3'), 'biz', null) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(4, '分类信息域', 1, text2ltree('1.4'), 'category', null) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(100, '地区', 3, text2ltree('1.3.100'), 'region', null) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(200, '项目域', 3, text2ltree('1.3.200'), 'project', null) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(300, '项目分类', 3, text2ltree('1.4.300'), 'prj_type', null) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(301, '环境影响评价', 300, text2ltree('1.4.300.301'), 'prj_type', 'pt_env') ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(302, '环保设施竣工验收', 300, text2ltree('1.4.300.301'), 'prj_type', 'pt_completion') ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(303, '场地调查', 300, text2ltree('1.4.300.301'), 'prj_type', 'pt_site') ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(304, '其他', 300, text2ltree('1.4.300.301'), 'prj_type', 'pt_other') ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(311, '报告书', 301, text2ltree('1.4.300.301.311'), 'prj_type', 'pt_env_rpt_book') ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(312, '报告表', 301, text2ltree('1.4.300.301.312'), 'prj_type', 'pt_env_rpt_table') ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(321, '报告书', 302, text2ltree('1.4.300.302.321'), 'prj_type', 'pt_comp_rpt_book') ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(322, '报告表', 302, text2ltree('1.4.300.302.322'), 'prj_type', 'pt_comp_rpt_table') ON CONFLICT DO NOTHING `,
        `insert into tb_acs_domain (id, name, pid, path ,category ,tag) values(1000, '组织机构域', 3, text2ltree('1.3.1000'), 'org', null) ON CONFLICT DO NOTHING `,

        `select setval('tb_acs_domain_id_seq', 20000 ) where (select nextval('tb_acs_domain_id_seq')) < 20000;`
    ]
}
