import {Model, DataTypes} from "sequelize";
import {AcsModule} from "@core-models/AcsModule";

export class AcsFunction extends Model {
    declare id: number;
    declare tag: string;
    declare module_id: number;
    declare name: string;
    declare api: string;
    declare check_auth: boolean;
    declare rw: number;

    static table_name = 'tb_acs_function';
    static attributes = {
        id: {
            type: DataTypes.INTEGER,
            autoIncrement: true,
            primaryKey: true,
            comment: '自增量id'
        },
        tag: {
            type: DataTypes.STRING(32),
            comment: '标记，与module组成api名称'
        },
        name: {
            type: DataTypes.STRING,
            comment: '功能项名称'
        },
        module_id: {
            type: DataTypes.INTEGER,
            comment: '父功能模块ID',
            allowNull: false,
            references: {
                model: AcsModule,
                key: 'id'
            }
        },
        api: {
            type: DataTypes.STRING,
            comment: 'api名称',
            allowNull: false,
            unique: true
        },
        check_auth: {
            type: DataTypes.BOOLEAN,
            defaultValue: true,
            comment: ' 访问时是否需要验证权限'
        },
        rw: {
            type: DataTypes.INTEGER,
            defaultValue: 3,
            comment: ' 读写类型，0 = 无，1 = 只写，2 = 只读，3 = 读写'
        },
    }

    static init_sqls = [
        `insert into tb_acs_function (id, module_id, tag, name, api, check_auth, rw) values
            (1, 2, 'add', '添加', 'acs.module.add', true, 1),
            (2, 2, 'get_tree', '获取树', 'acs.module.get_tree', true, 0),
            (3, 2, 'modify', '修改', 'acs.module.modify', true, 1),
            (4, 2, 'remove', '删除', 'acs.module.remove', true, 1),
            (5, 3, 'add', '添加', 'acs.function.add', true, 1),
            (6, 3, 'get_list', '获取列表', 'acs.function.get_list', true, 0),
            (7, 3, 'get_all', '获取所有', 'acs.function.get_all', true, 0),
            (8, 3, 'modify', '修改', 'acs.function.modify', true, 1),
            (9, 3, 'remove', '删除', 'acs.function.remove', true, 1),
            
            (10, 4, 'add', '添加', 'acs.application.add', true, 1),
            (11, 4, 'detail', '详情', 'acs.application.detail', true, 0),
            (12, 4, 'get_list', '获取列表', 'acs.application.get_list', true, 0),
            (13, 4, 'modify', '修改', 'acs.application.modify', true, 0),
            (14, 4, 'remove', '删除', 'acs.application.remove', true, 1),
            
           
            (20, 5, 'add', '添加', 'acs.domain.add', true, 1),
            (21, 5, 'get_all', '获取所有', 'acs.domain.get_all', true, 0),
            (22, 5, 'get_list', '获取列表', 'acs.domain.get_list', true, 0),
            (23, 5, 'get_tree', '获取树', 'acs.domain.get_tree', true, 0),
            (24, 5, 'modify', '修改', 'acs.domain.modify', true, 1),
            (25, 5, 'query', '查询', 'acs.domain.query', true, 0),
            (26, 5, 'remove', '删除', 'acs.domain.remove', true, 1),
            
            (30, 6, 'add', '添加', 'acs.role.add', true, 1),
            (31, 6, 'get_func_group_tree', '获取功能分组树', 'acs.role.get_func_group_tree', true, 0),
            (32, 6, 'get_list', '获取角色列表', 'acs.role.get_list', true, 0),
            (33, 6, 'modify', '修改角色信息', 'acs.role.modify', true, 1),
            (34, 6, 'remove', '删除', 'acs.role.remove', true, 1),
            (35, 6, 'get_funcs', '获取角色对应的功能项', 'acs.role.get_funcs', true, 0),
            (36, 6, 'set_funcs', '设置角色对应的功能项', 'acs.role.set_funcs', true, 1),
            
            (40, 7, 'add', '添加用户', 'acs.user.add', true, 1),
            (41, 7, 'get_list', '获取用户列表', 'acs.user.get_list', true, 0),
            (42, 7, 'modify', '修改用户信息', 'acs.user.modify', true, 1),
            (43, 7, 'remove', '删除用户', 'acs.user.remove', true, 1),
            (44, 7, 'reset_pass', '重置用户密码', 'acs.user.reset_pass', true, 1),
            (45, 7, 'get_domains', '获取用户的域', 'acs.user.get_domains', true, 0),
            (46, 7, 'set_domains', '设置用户的域', 'acs.user.set_domains', true, 1),
            (47, 7, 'get_roles', '获取角色列表', 'acs.user.get_roles', true, 0),
            (48, 7, 'set_roles', '设置角色', 'acs.user.set_roles', true, 1),
            
            (60, 8, 'get_domain_tree', '获取自己的域树', 'acs.self.get_domain_tree', false, 0),
            (61, 8, 'modify_pass', '修改密码', 'acs.self.modify_pass', false, 1),
            (62, 8, 'get_info', '取自己的账号信息', 'acs.self.get_info', false, 1),
            (63, 8, 'modify_info', '修改自己的账号信息', 'acs.self.modify_info', false, 1),
            (64, 8, 'get_roles', '取自己的角色', 'acs.self.get_roles', false, 0),
            (65, 8, 'modify_pass', '修改密码', 'acs.self.modify_pass', false, 1),
            (66, 8, 'reset_pass', '重置密码', 'acs.self.reset_pass', false, 1),
            
            (100, 101, 'get_list', '获取客户级别', 'cfg.customer_level.get_list', true, 0),
            (110, 102, 'get_list', '获取文档类型', 'cfg.doc_type.get_list', true, 0),
            (120, 103, 'get_list', '获取行业类型', 'cfg.industry_type.get_list', true, 0),
            (130, 104, 'get_list', '获取项目阶段', 'cfg.prj_phase.get_list', true, 0),
            (140, 105, 'get_list', '获取项目角色', 'cfg.prj_role.get_list', true, 0),
            (150, 106, 'get_tree', '获取项目类型', 'cfg.prj_type.get_tree', true, 0),
            
            (800, 180, 'get_tree', '获取部门树', 'cfg.org.get_tree', true, 0),
            (801, 180, 'add', '添加部门', 'cfg.org.add', true, 1),
            (802, 180, 'modify', '修改部门', 'cfg.org.modify', true, 1),
            (803, 180, 'remove', '删除部门', 'cfg.org.remove', true, 1),
            
            (810, 181, 'get_list', '获取员工列表', 'cfg.staff.get_list', true, 0),
            (811, 181, 'add', '添加员工', 'cfg.staff.add', true, 1),
            (812, 181, 'modify', '修改员工', 'cfg.staff.modify', true, 1),
            (813, 181, 'remove', '删除员工', 'cfg.staff.remove', true, 1),

            (1000, 201, 'get_list', '获取客户列表', 'biz.customer.get_list', true, 0),
            (1001, 201, 'add', '添加客户信息', 'biz.customer.add', true, 1),
            (1002, 201, 'modify', '修改客户信息', 'biz.customer.modify', true, 1),
            (1003, 201, 'remove', '删除客户信息', 'biz.customer.remove', true, 1),
            (1004, 201, 'detail', '获取客户详情', 'biz.customer.detail', true, 0),
            (1005, 201, 'stat', '获取客户统计数据', 'biz.customer.stat', true, 0),
            
            (1900, 281, 'count', '项目数量统计', 'report.prj.count', true, 0),
            

            (2020, 302, 'get_list', '获取项目列表', 'prj.info.get_list', true, 0),
            (2021, 302, 'add', '创建项目', 'prj.info.add', true, 1),
            (2022, 302, 'modify', '修改项目信息', 'prj.info.modify', true, 1),
            (2023, 302, 'remove', '删除项目信息', 'prj.info.remove', true, 1),
            (2024, 302, 'overview', '获取项目概览', 'prj.info.overview', true, 0),
            (2025, 302, 'get_logs', '获取项目动态', 'prj.info.get_logs', true, 0),
            (2026, 302, 'stat', '获取项目统计数据', 'prj.info.stat', true, 0),

            (2040, 303, 'get_list', '获取项目组成员列表', 'prj.member.get_list', true, 0),
            (2041, 303, 'add', ' 添加项目组成员', 'prj.member.add', true, 1),
            (2042, 303, 'modify', '修改项目组成员', 'prj.member.modify', true, 1),
            (2043, 303, 'remove', '删除项目组成员', 'prj.member.remove', true, 1),
            (2044, 303, 'apply_add', '申请添加项目组成员', 'prj.member.apply_add', true, 0),
            (2045, 303, 'apply_remove', '申请删除项目组成员', 'prj.member.apply_remove', true, 0),
            (2046, 303, 'check', '审核项目组成员调整申请', 'prj.member.check', true, 1),

            (2060, 304, 'get_tasks', '获取项目计划', 'prj.plan.get_tasks', true, 0),
            (2061, 304, 'add_task', '添加任务项', 'prj.plan.add_task', true, 1),
            (2062, 304, 'modify_task', '修改任务项信息', 'prj.plan.modify_task', true, 1),
            (2063, 304, 'remove_task', '删除任务项', 'prj.plan.remove_task', true, 1),
            (2064, 304, 'detail', '获取完整任务计划信息', 'prj.plan.detail', true, 0),
            (2065, 304, 'task_detail', '获取任务项详情', 'prj.plan.task_detail', true, 0),
            (2066, 304, 'sort_task', '调整任务项顺序', 'prj.plan.sort_task', true, 1),
            (2067, 304, 'cancel_task', '中止任务项', 'prj.plan.cancel_task', true, 1),
            (2068, 304, 'set_progress', '设置进度', 'prj.plan.set_progress', true, 1),
            (2069, 304, 'get_check_flow', '获取审核流程', 'prj.plan.get_check_flow', true, 0),
            (2070, 304, 'set_check_flow', '设置审核流程', 'prj.plan.set_check_flow', true, 1),
            (2071, 304, 'get_logs', '获取任务动态', 'prj.plan.get_logs', true, 0),
            (2072, 304, 'recover_task', '取消删除任务', 'prj.plan.recover_task', true, 1),
            
            (2080, 305, 'get_list', '获取交付物列表', 'prj.outcome.get_list', true, 0),
            (2081, 305, 'add', ' 添加交付物', 'prj.outcome.add', true, 1),
            (2082, 305, 'modify', '修改交付物', 'prj.outcome.modify', true, 1),
            (2083, 305, 'remove', '删除交付物', 'prj.outcome.remove', true, 1),
            (2084, 305, 'detail', '获取交付物详情', 'prj.outcome.detail', true, 0),
            (2085, 305, 'upload', '上传交付物文件', 'prj.outcome.upload', true, 1),
            (2086, 305, 'download', '下载交付物文件', 'prj.outcome.download', true, 0),
            (2087, 305, 'remove_file', '删除交付物文件', 'prj.outcome.remove_file', true, 0),
            
            (2120, 307, 'get_list', '获取合同列表', 'prj.contract.get_list', true, 0),
            (2121, 307, 'add', ' 添加合同', 'prj.contract.add', true, 1),
            (2122, 307, 'modify', '修改合同信息', 'prj.contract.modify', true, 1),
            (2123, 307, 'remove', '删除合同', 'prj.contract.remove', true, 1),
            (2124, 307, 'detail', '获取合同详情', 'prj.contract.detail', true, 0),
            (2125, 307, 'upload_doc', '上传合同文档', 'prj.contract.upload_doc', true, 1),
            (2126, 307, 'download_doc', '下载合同文档', 'prj.contract.download_doc', true, 0),
            (2127, 307, 'stat', '获取合同统计数据', 'prj.contract.stat', true, 0),
            
            (2140, 308, 'get_list', '获取周报列表', 'prj.week_report.get_list', true, 0),
            (2141, 308, 'add', ' 添加周报', 'prj.week_report.add', true, 1),
            (2142, 308, 'modify', '修改周报信息', 'prj.week_report.modify', true, 1),
            (2143, 308, 'remove', '删除周报', 'prj.week_report.remove', true, 1),
            (2144, 308, 'detail', '获取周报详情', 'prj.week_report.detail', true, 0),
            (2145, 308, 'upload_file', '上传周报附件', 'prj.week_report.upload_file', true, 1),
            (2146, 308, 'download_file', '下载周报附件', 'prj.week_report.download_file', true, 0),
            
            (2160, 309, 'get_list', '获取项目文档列表', 'prj.doc.get_list', true, 0),
            (2161, 309, 'upload', ' 添加项目文档', 'prj.doc.upload', true, 1),
            (2162, 309, 'download', '下载项目文档', 'prj.doc.download', true, 0),
            (2163, 309, 'remove', '删除项目文档', 'prj.doc.remove', true, 1),
            
            (2180, 310, 'milestone', '查看项目里程碑', 'prj.kanban.milestone', true, 0),
            
            (2200, 311, 'get_list', '获取我的工作列表', 'prj.work.get_list', true, 0),
            (2201, 311, 'detail', '获取工作详情', 'prj.work.detail', true, 0),
            (2202, 311, 'submit', '提交工作', 'prj.work.submit', true, 1),
            (2203, 311, 'upload_file', '上传工作项附件', 'prj.work.upload_file', true, 1),
            (2204, 311, 'stat', '获取工作项统计信息', 'prj.work.stat', true, 0)

         ON CONFLICT DO NOTHING `,
        `select setval('tb_acs_function_id_seq', 20000 ) where (select nextval('tb_acs_function_id_seq')) < 20000;`
    ]
}
