import {Model, DataTypes} from "sequelize";

export class AcsModule extends Model {
    declare id: number;
    declare name: string;
    declare pid: number;
    declare path: string;
    declare path_name: string;
    declare ui_show: boolean;
    declare tag: string;
    declare order_id: number;

    static table_name = 'tb_acs_module';
    static attributes = {
        id: {
            type: DataTypes.INTEGER,
            autoIncrement: true,
            primaryKey: true,
            comment: '自增量id'
        },
        tag: {
            type: DataTypes.STRING(32),
            comment: '标记，作为restful api功能的前缀，如取列表功能（get_list)，前缀是模块层次（sys.module.get_list)'
        },
        name: {
            type: DataTypes.STRING,
            comment: '功能模块名称',

        },
        pid: {
            type: DataTypes.INTEGER,
            comment: '父节点id',
            allowNull: true,
            references: {
                model: AcsModule,
                key: 'id'
            },
        },
        memo: {
            type: DataTypes.STRING,
            comment: '备注',
            allowNull: true,
            defaultValue: ''
        },
        ui_show: {
            type: DataTypes.BOOLEAN,
            defaultValue: true,
            comment: '是否显示在界面菜单上'
        },
        path: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '树状结构节点路径'
        },
        path_name: {
            type: DataTypes.STRING,
            unique: true,
            commnet: '路径名，即api名称'
        },
        order_id: {
            type: DataTypes.INTEGER,
            defaultValue: 0,
            comment:'显示在ui上时的排序号'
        },

    }

    static init_sqls = [
        `alter table tb_acs_module alter column path type ltree using path::ltree; `,
        `insert into tb_acs_module (id, tag, name, pid, path, path_name) values
            (1, 'acs', '系统基础管理', null, text2ltree('1'), 'acs'),
            (2, 'module', '功能项分组管理', 1, text2ltree('1.2'), 'acs.module'),
            (3, 'function', '功能项管理', 1, text2ltree('1.3'), 'acs.function'),
            
            (4, 'application', '应用管理', 1, text2ltree('1.4'), 'acs.application'),
            (5, 'domain', '域管理', 1, text2ltree('1.5'), 'acs.domain'),
            (6, 'role', '角色管理', 1, text2ltree('1.6'), 'acs.role'),
            (7, 'user', '系统用户管理', 1, text2ltree('1.7'), 'acs.user'),
            (8, 'self', '账号自助', 1, text2ltree('1.8'), 'acs.self'),


            (100, 'cfg', '配置接口', null, text2ltree('100'), 'cfg'),
            (101, 'customer_level', '客户级别', 100, text2ltree('100.101'), 'cfg.customer_level'),
            (102, 'doc_type', '文档类型', 100, text2ltree('100.102'), 'cfg.doc_type'),
            (103, 'industry_type', '行业类型', 100, text2ltree('100.103'), 'cfg.industry_type'),
            (104, 'prj_phase', '项目阶段', 100, text2ltree('100.104'), 'cfg.prj_phase'),
            (105, 'prj_role', '项目角色', 100, text2ltree('100.105'), 'cfg.prj_role'),
            (106, 'prj_type', '项目类型', 100, text2ltree('100.106'), 'cfg.prj_type'),
            
            (180, 'org', '组织机构管理', 100, text2ltree('100.180'), 'cfg.org'),
            (181, 'staff', '员工管理', 100, text2ltree('100.181'), 'cfg.staff'),
            
            (200, 'biz', '营销接口', null, text2ltree('200'), 'biz'),
            (201, 'customer', '客户管理', 200, text2ltree('200.201'), 'biz.customer'),

            (280, 'report', '报表', null, text2ltree('280'), 'dashboard'),
            (281, 'prj', '项目统计', null, text2ltree('280.281'), 'dashboard.prj'),
            
            
            (300, 'prj', '项目管理', null, text2ltree('300'), 'prj'),
            (301, 'template', '项目模板管理', 300, text2ltree('300.301'), 'prj.template'),
            (302, 'info', '项目信息管理', 300, text2ltree('300.302'), 'prj.info'),
            (303, 'member', '项目组成员管理', 300, text2ltree('300.303'), 'prj.member'),
            (304, 'plan', '项目计划管理', 300, text2ltree('300.304'), 'prj.plan'),
            (305, 'outcome', '项目交付物', 300, text2ltree('300.305'), 'prj.outcome'),
            (306, 'apply', '项目申请相关接口', 300, text2ltree('300.306'), 'prj.apply'),
            (307, 'contract', '项目合同管理', 300, text2ltree('300.307'), 'prj.contract'),
            (308, 'week_report', '项目周报管理', 300, text2ltree('300.308'), 'prj.week_report'),
            (309, 'doc', '项目文档管理', 300, text2ltree('300.309'), 'prj.doc'),
            (310, 'kanban', '项目看板', 300, text2ltree('300.310'), 'prj.kanban'),
            (311, 'work', '我的工作', 300, text2ltree('300.311'), 'prj.work')

             ON CONFLICT DO NOTHING `,
        `select setval('tb_acs_module_id_seq', 20000 ) where (select nextval('tb_acs_module_id_seq')) < 20000;`
    ]
}
