/**
 * 小程序客户信息
 */

import {Model, DataTypes} from "sequelize";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {Sequelize} from "sequelize";

export class AcsMpClient extends Model {
    static table_name = 'tb_acs_mp_client';

    declare id: number;
    declare open_id: string | null;
    declare card_id: string | null;
    declare name: string | null;       // 昵称
    declare avatar_url: string | null;      // 头像图片链接
    declare union_id: string | null;
    declare mobile: string | null;          // 手机号
    declare platform: number;               // 小程序平台，1=微信，2=支付宝
    declare token: string | null;           // 由平台自己生成的token，用于登录后的交互认证
    declare client_type: number;             // 小程序类型， 1=管理端
    declare user_id: string;
    declare blocked: boolean;

    static attributes = {
        id: {
            type: DataTypes.INTEGER,
            autoIncrement: true,
            unique: true,
            primaryKey: true,
            comment: '自增量id'
        },
        open_id: {
            type: DataTypes.STRING,
            allowNull: true,
            defaultValue: ''
        },
        name: {
            type: DataTypes.STRING,
            allowNull: false,
            defaultValue: ''
        },
        avatar_url: {
            type: DataTypes.STRING,
            allowNull: true
        },
        union_id: {
            type: DataTypes.STRING,
            allowNull: true
        },
        mobile: {
            type: DataTypes.STRING,
            allowNull: true,
        },
        platform: {
            type: DataTypes.INTEGER,
            comment: '平台，0=未绑定小程序的实体卡，1=微信，2=支付宝',
            defaultValue: 0
        },
        client_type: {
            type: DataTypes.INTEGER,
            comment: '小程序类型， 1=管理端',
            defaultValue: 1
        },
        token: {
            type: DataTypes.STRING,
            allowNull: true
        },
        user_id: {
            type: DataTypes.STRING,
            allowNull: true,
            references: {
                model: AcsUserInfo,
                key: 'id'
            },
        },
        blocked: {
            type: DataTypes.BOOLEAN,
            allowNull: false,
            defaultValue: false,
            comment: '是否暂停使用'
        },

    };

    static indexes = [
        {fields: ['open_id', 'mobile', 'client_type'], unique: true},
        {fields: ['mobile']},
        {fields: ['platform']},
        {fields: ['client_type']}
    ]

    static associate(sequelize: Sequelize) {
        try {

            AcsMpClient.belongsTo(AcsUserInfo, {foreignKey: 'user_id', targetKey: 'id', as: 'UserInfo'});
            AcsUserInfo.hasMany(AcsMpClient, {foreignKey: 'user_id', sourceKey: 'id'});

        } catch (e) {
            console.log(e);
        }
    }
}
