import {Model} from "sequelize";
import {Sequelize, DataTypes}  from 'sequelize';
import {AcsRole} from "@core-models/AcsRole";
import {AcsFunction} from "@core-models/AcsFunction";

/**
 * 角色功能项对应表
 */

export class AcsRoleFunction extends Model {
    declare func_id: number;
    declare role_id: string;


    static table_name = 'tb_acs_role_function';

    static attributes = {
        role_id: {
            type: DataTypes.STRING,
            primaryKey: true,
            comment: '角色',
            references: {
                model: AcsRole,
                key: 'id'
            }
        },
        func_id: {
            type: DataTypes.INTEGER,
            primaryKey: true,
            comment: '功能项编号',
            references: {
                model: AcsFunction,
                key: 'id'
            }
        },

    }

    static indexes = [
        {fields: ['func_id', 'role_id']}
    ]

    static associate(sequelize: Sequelize) {
        try {
            AcsFunction.belongsToMany(AcsRole, { through: AcsRoleFunction, foreignKey: 'id', otherKey: 'role_id' });
            AcsRole.belongsToMany(AcsFunction, { through: AcsRoleFunction, foreignKey: 'id', otherKey: 'func_id' });
            AcsRoleFunction.belongsTo(AcsFunction, {foreignKey: 'func_id', targetKey: 'id'});
            AcsRoleFunction.belongsTo(AcsRole, {foreignKey: 'role_id', targetKey: 'id'});
            AcsFunction.hasMany(AcsRoleFunction, {foreignKey: 'func_id', sourceKey: 'id'});
            AcsRole.hasMany(AcsRoleFunction, {foreignKey: 'role_id', sourceKey: 'id'});
        } catch (e) {
            console.log(e);
        }
    }

    static init_sqls = [
        `insert into tb_acs_role_function (role_id, func_id) values
            ('admin', 20),
            ('admin', 21),
            ('admin', 22),
            ('admin', 23),
            ('admin', 24),
            ('admin', 25),
            ('admin', 26),
            ('admin', 30),
            ('admin', 31),
            ('admin', 32),
            ('admin', 33),
            ('admin', 34),
            ('admin', 35),
            ('admin', 36),
            ('admin', 40),
            ('admin', 41),
            ('admin', 42),
            ('admin', 43),
            ('admin', 44),
            ('admin', 45),
            ('admin', 46),
            ('admin', 47),
            ('admin', 48),
            ('admin', 60),
            ('admin', 61),
            ('admin', 62),
            ('admin', 63),
            ('admin', 64),
            ('admin', 66),
            
            ('admin', 100),
            ('admin', 110),
            ('admin', 120),
            ('admin', 130),
            ('admin', 140),
            ('admin', 150),
            
            ('admin', 800),
            ('admin', 801),
            ('admin', 802),
            ('admin', 803),
            
            ('admin', 810),
            ('admin', 811),
            ('admin', 812),
            ('admin', 813),

            ('admin', 1000),
            ('admin', 1001),
            ('admin', 1002),
            ('admin', 1003),
            ('admin', 1004),
            ('admin', 1005),
            
            ('admin', 1900),
            
            ('admin', 2020),
            ('admin', 2021),
            ('admin', 2022),
            ('admin', 2023),
            ('admin', 2024),
            ('admin', 2025),
            ('admin', 2026),

            ('admin', 2040),
            ('admin', 2041),
            ('admin', 2042),
            ('admin', 2043),
            ('admin', 2044),
            ('admin', 2045),
            ('admin', 2046),

            ('admin', 2060),
            ('admin', 2061),
            ('admin', 2062),
            ('admin', 2063),
            ('admin', 2064),
            ('admin', 2065),
            ('admin', 2066),
            ('admin', 2067),
            ('admin', 2068),
            ('admin', 2069),
            ('admin', 2070),
            ('admin', 2071),
            ('admin', 2072),
            
            ('admin', 2080),
            ('admin', 2081),
            ('admin', 2082),
            ('admin', 2083),
            ('admin', 2084),
            ('admin', 2085),
            ('admin', 2086),
            ('admin', 2087),
            
            ('admin', 2120),
            ('admin', 2121),
            ('admin', 2122),
            ('admin', 2123),
            ('admin', 2124),
            ('admin', 2125),
            ('admin', 2126),
            ('admin', 2127),
            
            ('admin', 2140),
            ('admin', 2141),
            ('admin', 2142),
            ('admin', 2143),
            ('admin', 2144),
            ('admin', 2145),
            ('admin', 2146),
            
            ('admin', 2160),
            ('admin', 2161),
            ('admin', 2162),
            ('admin', 2163),
            
            ('admin', 2180),
            
            ('admin', 2200),
            ('admin', 2201),
            ('admin', 2202),
            ('admin', 2203),
            ('admin', 2204)
            
            ON CONFLICT DO NOTHING `
    ]
}
