import {Model} from "sequelize";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {AcsDomain} from "@core-models/AcsDomain";
import { Sequelize, DataTypes }  from 'sequelize';

/**
 * 账号域对应表
 */

export class AcsUserDomain extends Model {
    declare user_id: string;
    declare domain_id: number;


    static table_name = 'tb_acs_user_domain';

    static attributes = {
        id: {
            type: DataTypes.INTEGER,
            autoIncrement: true,
            comment: '自增量id'
        },
        user_id: {
            type: DataTypes.STRING,
            primaryKey: true,
            comment: '用户账号',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        domain_id: {
            type: DataTypes.INTEGER,
            primaryKey: true,
            comment: '所属域',
            references: {
                model: AcsDomain,
                key: 'id'
            }
        },

    }

    static indexes = [
        {fields: ['user_id', 'domain_id']}
    ]

    static associate(sequelize: Sequelize) {
        try {
            AcsUserInfo.belongsToMany(AcsDomain, { through: AcsUserDomain, foreignKey: 'id', otherKey: 'domain_id' });
            AcsDomain.belongsToMany(AcsUserInfo, { through: AcsUserDomain, foreignKey: 'id', otherKey: 'user_id' });
            AcsUserDomain.belongsTo(AcsUserInfo, {foreignKey: 'user_id', targetKey: 'id'});
            AcsUserDomain.belongsTo(AcsDomain, {foreignKey: 'domain_id', targetKey: 'id'});
            AcsUserInfo.hasMany(AcsUserDomain, {foreignKey: 'user_id', sourceKey: 'id'});
            AcsDomain.hasMany(AcsUserDomain, {foreignKey: 'domain_id', sourceKey: 'id'});
        } catch (e) {
            console.log(e);
        }
    }

    static init_sqls = [
        `insert into tb_acs_user_domain (user_id, domain_id) values('administrator', 1) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_user_domain (user_id, domain_id) values('admin', 2) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_user_domain (user_id, domain_id) values('admin', 3) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_user_domain (user_id, domain_id) values('admin', 4) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_user_domain (user_id, domain_id) values('admin', 100) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_user_domain (user_id, domain_id) values('master', 1000) ON CONFLICT DO NOTHING `,
    ]
}
