import {Model, DataTypes} from "sequelize";

export class AcsUserInfo extends Model {
    declare id: string;
    declare name: string;
    declare pass: string;
    declare mobile: string;
    declare email: string;
    declare status: number;
    declare ext_info: any;
    declare memo: string;

    static table_name = 'tb_acs_user';
    static attributes = {
        id: {
            type: DataTypes.STRING,
            primaryKey: true,
            unique: true,
            comment: '用户账号'
        },
        name: {
            type: DataTypes.STRING,
            comment: '用户名称'
        },
        pass: {
            type: DataTypes.STRING,
            comment: '密码，md5 32位 小写'
        },
        mobile: {
            type: DataTypes.STRING,
            allowNull: true,
            unique: true,
            comment: '手机号'
        },
        email: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '邮箱号'
        },
        reg_time: {
            type: DataTypes.DATE,
            comment: '注册时间',
            defaultValue: DataTypes.NOW
        },
        act_time: {
            type: DataTypes.DATE,
            comment: '最新活动时间'
        },
        status: {
            type: DataTypes.INTEGER,
            comment: '状态，0=锁定，1=正常'
        },
        ext_info: {
            type: DataTypes.JSONB,
            comment: '扩展信息',
            defaultValue: {}
        },
        memo: {
            type: DataTypes.TEXT,
            comment: '备注'
        }
    }

    static init_sqls = [
        `insert into tb_acs_user (id, name, pass, status) values('administrator', '系统', 'd9cbfed06b47eac90c3db08fdcb57616', 1) ON CONFLICT DO NOTHING `,
        `insert into tb_acs_user (id, name, pass, status) values('admin', '系统管理员', 'e10adc3949ba59abbe56e057f20f883e', 1) ON CONFLICT DO NOTHING `,
        //`insert into tb_acs_user (id, name, pass, status) values('test', '测试账号', '', 1) ON CONFLICT DO NOTHING `,
        //`insert into tb_acs_user (id, name, pass, status) values('master', '公司管理员', 'e10adc3949ba59abbe56e057f20f883e', 1) ON CONFLICT DO NOTHING `,

    ]
}
