import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';
import {BizCustomer} from "@core-models/BizCustomer";
import {PrjInfo} from "@core-models/PrjInfo";
import {AcsUserInfo} from "@core-models/AcsUserInfo";

/**
 * 项目合同信息表
 */

export class BizContractInfo extends Model {
    declare id: string;
    declare doc_uploaded: boolean;
    declare pdf_uploaded: boolean;
    declare doc_id: string;
    declare doc_name: string;
    declare doc_uploaded_at: string;
    declare doc_size: number;
    declare pdf_id: string;
    declare pdf_name: string;
    declare pdf_uploaded_at: string;
    declare pdf_size: number;
    declare handler_id: string;

    static table_name = 'tb_biz_contract_info';

    static attributes = {
        id: {
            type: DataTypes.STRING(16),
            primaryKey: true,
            comment: '合同编号',
        },
        name: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '合同名称',
        },
        customer_id: {
            type: DataTypes.STRING(16),
            allowNull: false,
            comment: '客户id',
            references: {
                model: BizCustomer,
                key: 'id'
            }
        },
        prj_id: {
            type: DataTypes.STRING(16),
            allowNull: true,
            comment: '项目id',
            // references: {
            //     model: PrjInfo,
            //     key: 'id'
            // }
        },
        amount: {
            type: DataTypes.DECIMAL(10,4),
            allowNull: false,
            comment: '合同总金额'
        },
        handler_id: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '合同签订人id',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        created_at: {
            type: DataTypes.DATE,
            allowNull: false,
            comment: '创建时间',
            default: DataTypes.NOW
        },
        updated_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '最近修改时间'
        },
        signed_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '合同签订日期（YYYY-MM-DD）'
        },
        begin_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '合同起始日期（YYYY-MM-DD）'
        },
        end_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '合同终止日期（YYYY-MM-DD)'
        },
        payments: {
            type: DataTypes.JSONB,
            allowNull: true,
            comment: '收款约定'
        },
        creator_id: {
            type: DataTypes.STRING,
            comment: '创建者账号',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        doc_id: {
            type:DataTypes.STRING,
            allowNull: true,
            comment: '合同打印件 oss object name'
        },
        doc_name: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '合同打印件文件名'
        },
        doc_uploaded: {
            type: DataTypes.BOOLEAN,
            allowNull: false,
            defaultValue: false,
            comment: '合同打印件是否已上传'
        },
        doc_uploaded_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '合同打印件上传时间'
        },
        doc_size: {
            type: DataTypes.INTEGER,
            comment: '合同打印件文件大小',
            allowNull: true
        },
        pdf_id: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '合同扫描件 oss object name'
        },
        pdf_name: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '合同扫描件文件名'
        },
        pdf_uploaded: {
            type: DataTypes.BOOLEAN,
            allowNull: false,
            defaultValue: false,
            comment: '合同扫描件是否已上传'
        },
        pdf_uploaded_at: {
            type: DataTypes.DATE,
            comment: '合同扫描件上传时间',
            allowNull: true
        },
        pdf_size: {
            type: DataTypes.INTEGER,
            comment: '合同扫描件文件大小',
            allowNull: true
        },
        comment: {
            type: DataTypes.TEXT,
            allowNull: true,
            comment: '合同摘要'
        }

    }

    static indexes = [
        {fields: ['created_at']},
        {fields: ['name']}
    ]

    static associate(sequelize: Sequelize) {
        try {
            // AcsDomain.hasMany(BizCustomer, {foreignKey: 'region_id', sourceKey: 'id'});
            // BizCustomer.belongsTo(AcsDomain, {foreignKey: 'region_id', targetKey: 'id'});
            // BizCustomerLevel.hasMany(BizCustomer, {foreignKey: 'level_id', sourceKey: 'id'});
            // BizCustomer.belongsTo(BizCustomerLevel, {foreignKey: 'level_id', targetKey: 'id'});
            // BizCustomerIndustry.hasMany(BizCustomer, {foreignKey: 'industry_id', sourceKey: 'id'});
            // BizCustomer.belongsTo(BizCustomerIndustry, {foreignKey: 'industry_id', targetKey: 'id'});
        } catch (e) {
            console.log(e);
        }
    }

    static init_sqls = [
    ]
}
