import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';
import {AcsDomain} from "@core-models/AcsDomain";
import {BizCustomerLevel} from "@core-models/BizCustomerLevel";
import {BizCustomerIndustry} from "@core-models/BizCustomerIndustry";
import {AcsUserInfo} from "@core-models/AcsUserInfo";

/**
 * 客户信息表
 */

export class BizCustomer extends Model {
    declare id: string;

    static table_name = 'tb_biz_customer';

    static attributes = {
        id: {
            type: DataTypes.STRING(16),
            primaryKey: true,
            comment: '客户编号',
        },
        name: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '客户名称',
        },
        region_id: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '所属地区',
            references: {
                model: AcsDomain,
                key: 'id'
            }
        },
        level_id: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '客户级别',
            references: {
                model: BizCustomerLevel,
                key: 'id'
            }
        },
        industry_id: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '客户行业分类id',
            references: {
                model: BizCustomerIndustry,
                key: 'id'
            }
        },
        link_man: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '联系人姓名'
        },
        link_phone: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '联系人电话'
        },
        bizman_id: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '市场负责人账号id',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        address: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '客户实际经营地址'
        },
        invoice_title: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '发标抬头'
        },
        tax_no: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '客户税号'
        },
        bank_name: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '客户开户行'
        },
        bank_account: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '客户银行账号'
        },
        invoice_phone: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '开票资料中的电话'
        },
        invoice_addr: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '开票资料地址'
        },
        memo: {
            type: DataTypes.TEXT,
            allowNull: true,
            comment: '客户备注'
        },
        created_at: {
            type: DataTypes.DATE,
            allowNull: false,
            comment: '创建时间',
            default: DataTypes.NOW
        },
        updated_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '最近修改时间'
        }
    }

    static indexes = [
        {fields: ['created_at']},
        {fields: ['name']}
    ]

    static associate(sequelize: Sequelize) {
        try {
            AcsDomain.hasMany(BizCustomer, {foreignKey: 'region_id', sourceKey: 'id'});
            BizCustomer.belongsTo(AcsDomain, {foreignKey: 'region_id', targetKey: 'id'});
            BizCustomerLevel.hasMany(BizCustomer, {foreignKey: 'level_id', sourceKey: 'id'});
            BizCustomer.belongsTo(BizCustomerLevel, {foreignKey: 'level_id', targetKey: 'id'});
            BizCustomerIndustry.hasMany(BizCustomer, {foreignKey: 'industry_id', sourceKey: 'id'});
            BizCustomer.belongsTo(BizCustomerIndustry, {foreignKey: 'industry_id', targetKey: 'id'});
        } catch (e) {
            console.log(e);
        }
    }

    static init_sqls = [
    ]
}
