import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {BpmnModel} from "@core-models/BpmnModel";
import {PrjInfo} from "./PrjInfo";
import {PrjPlanTask} from "./PrjPlanTask";

/**
 * 流程实例表
 */

export class BpmnCase extends Model {
    declare id: string;
    declare model_id: string;
    declare model: string;
    declare started_at: string;
    declare completed_at: string;
    declare creator_id: string;
    declare state: any;
    declare prj_id: string;
    declare task_id: string;

    static table_name = 'tb_bpmn_case';

    static attributes = {
        id: {
            type: DataTypes.STRING(16),
            primaryKey: true,
            comment: '流程实例的id',
        },
        model_id: {
            type: DataTypes.STRING(16),
            comment: '流程模型id',
        },
        model: {
            type: DataTypes.TEXT,
            allowNull: false,
            comment: '模型快照，创建流程时从BpmnModel中复制'
        },
        started_at: {
            type: DataTypes.DATE,
            allowNull: false,
            comment: '启动时间'
        },
        completed_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '完成时间'
        },
        prj_id: {
            type: DataTypes.STRING(16),
            allowNull: true,
            comment: '项目id',
            references: {
                model: PrjInfo,
                key: 'id'
            }
        },
        task_id: {
            type: DataTypes.STRING(16),
            allowNull: true,
            comment: '计划任务id',
            references: {
                model: PrjPlanTask,
                key: 'id'
            }
        },
        creator_id: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '实例创建人账号',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        state: {
            type: DataTypes.JSONB,
            allowNul: true,
            comment: '流程实例序列化（用于暂存状态）'
        }
    }

    static indexes = []

    static associate(sequelize: Sequelize) {}

    static init_sqls = []
}
