import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {PrjInfo} from "./PrjInfo";
import {BpmnCase} from "./BpmnCase";
import {PrjPlanTask} from "./PrjPlanTask";

/**
 * 流程工作项表
 */

export class BpmnWork extends Model {
    declare id: string;
    declare execution_id: string;
    declare name: string;
    declare activity_id: string;
    declare owner: string;
    declare prj_id: string;
    declare task_id: string;
    declare started_at: string;
    declare completed_at: string;
    declare process_type: number;
    declare status: number;

    static table_name = 'tb_bpmn_work';

    static attributes = {
        id: {
            type: DataTypes.STRING,
            primaryKey: true,
            comment: '工作id',
        },
        execution_id: {
            type: DataTypes.STRING,
            comment: '工作的execution id，多个并行任务的execution id相同'
        },
        name: {
            type: DataTypes.STRING,
            comment: '工作名称'
        },

        activity_id: {
            type: DataTypes.STRING,
            comment: 'activity id'
        },
        prj_id: {
            type: DataTypes.STRING(16),
            allowNull: true,
            comment: '项目id',
            references: {
                model: PrjInfo,
                key: 'id'
            }
        },
        task_id: {
            type: DataTypes.STRING(16),
            allowNull: true,
            comment: '任务id',
            references: {
                model: PrjPlanTask,
                key: 'id'
            }
        },
        assigned_to: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '任务归属人账号',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        handler: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '任务执行人账号，为空表示系统自动处理',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        started_at: {
            type: DataTypes.DATE,
            comment: '任务起始时间'
        },
        completed_at: {
            type: DataTypes.DATE,
            comment: '任务完成时间'
        },
        due_at: {
            type: DataTypes.DATE,
            comment: '过期时间'
        },
        case_id: {
            type: DataTypes.STRING(16),
            comment: 'flow case id',
            references: {
                model: BpmnCase,
                key: 'id'
            }
        },
        process_type: {
            type: DataTypes.INTEGER,
            comment: '任务处理类型，0=自动任务，1=待办，2=待阅'
        },
        show_in_my_works: {
            type: DataTypes.BOOLEAN,
            comment: '是否显示到我的工作中',
            defaultValue: false
        },
        target_type: {
            type: DataTypes.STRING,
            comment: '目标类型'
        },
        params: {
            type: DataTypes.JSONB,
            comment: '相关参数'
        },
        form: {
            type: DataTypes.JSONB,
            comment: '表单'
        },
        status: {
            type: DataTypes.INTEGER,
            comment: '任务状态，0=进行中，1=已过期，2=已完成',
            defaultValue: 0
        },
        desc: {
            type: DataTypes.TEXT,
            comment: '任务详细描述，通常用于待阅任务，如驳回时的信息、催办信息等'
        }
    }

    static indexes = []

    static associate(sequelize: Sequelize) {}

    static init_sqls = []
}
