import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {PrjInfo} from "@core-models/PrjInfo";
import {PrjFileCategory} from "@core-models/PrjFileCategory";

/**
 * 项目文档或附件库表
 */

export class PrjFile extends Model {
    declare id: string;
    declare prj_id: string;
    declare filename: string;
    declare uploaded_at: string;
    declare dependent_id: string;
    declare uploaded: boolean;
    declare size: number;

    static table_name = 'tb_prj_file';

    static attributes = {
        id: {
            type: DataTypes.STRING,
            primaryKey: true,
            comment: '文档或附件的object name',
        },
        // object_name: {
        //     type: DataTypes.STRING,
        //     allowNull: false,
        //     comment: 'oss object name'
        // },
        category_id: {
            type: DataTypes.STRING(16),
            allowNull: false,
            comment: '文档类别',
            references: {
                model: PrjFileCategory,
                key: 'id'
            }
        },
        prj_id: {
            type: DataTypes.STRING(16),
            allowNull: false,
            comment: '项目id',
            references: {
                model: PrjInfo,
                key: 'id'
            }
        },
        dependent_id: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '所依赖的相关id，如周报id等，如果是自由上传的文件，此字段为null',
        },
        uploaded: {
            type: DataTypes.BOOLEAN,
            allowNull: false,
            defaultValue: false,
            comment: '申请上传地址后，有没有真正上传'
        },
        req_upload_time: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '请求获取上传url时间'
        },
        uploaded_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '上传完成时间'
        },
        creator_id: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '上传人账号',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        filename: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '原始文件名'
        },
        size: {
            type: DataTypes.INTEGER,
            allowNull: true,
            comment: '文件大小（Bytes）',
            defaultValue: 0
        }
    }

    static indexes = [

    ]

    static associate(sequelize: Sequelize) {

    }

    static init_sqls = [

    ]
}
