import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';

/**
 * 项目文件分类表
 */

export class PrjFileCategory extends Model {
    declare id: string;
    declare name: string;
    declare order_index: number;
    declare allow_upload: boolean;

    static table_name = 'tb_prj_file_category';

    static attributes = {
        id: {
            type: DataTypes.STRING(16),
            primaryKey: true,
            comment: '编号',
        },
        name: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '名称',
        },
        color: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '标签颜色',
            defaultValue: 'gray'
        },
        order_index: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '顺序号'
        },
        allow_upload: {
            type: DataTypes.BOOLEAN,
            allowNull: false,
            defaultValue: false,
            comment: '是否允许自由上传'
        }
    }

    static indexes = [

    ]

    static associate(sequelize: Sequelize) {

    }

    static init_sqls = [
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('contract', '合同文档', 'pinkpurple', false, 10) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('project_set_up', '立项文档', 'gold', false, 20) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('meeting', '沟通纪要', 'cyan', true, 30) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('attachments', '附图附件', 'red', true, 40) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('technology', '技术资料', 'green', true, 50) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('literature', '参考文献', 'arcoblue', true, 60) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('media', '影像资料', 'green', true, 70) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('intermediate', '中间文档', 'orange', true, 80) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('submited', '报审文档', 'red', true, 90) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('outcome', '交付文档', 'arcoblue', true, 100) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('week_report', '周报附件', 'gray', false, 110) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjFileCategory.table_name} (id, name, color, allow_upload, order_index) values ('other', '其它文档', 'gray', true, 120) ON CONFLICT DO NOTHING; `

    ]
}
