import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';
import {AcsDomain} from "@core-models/AcsDomain";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {PrjPhaseDefine} from "./PrjPhaseDefine";
import {BizCustomer} from "@core-models/BizCustomer";
import {BizContractInfo} from "@core-models/BizContractInfo";

/**
 * 项目信息表
 */

export class PrjInfo extends Model {
    declare id: string;
    declare phase_id: string;
    declare flow_case_id: string;
    declare leader_id: string;
    declare bizman_id: string;
    declare progress: number;
    declare checkers: any;
    declare contract_id: string;
    declare created_at: string;
    declare started_at: string;
    declare deliver_at: string;

    static table_name = 'tb_prj_info';

    static attributes = {
        id: {
            type: DataTypes.STRING(16),
            primaryKey: true,
            comment: '项目编号',
        },
        name: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '项目名称',
        },
        region_id: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '所属地区',
            references: {
                model: AcsDomain,
                key: 'id'
            }
        },
        phase_id: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '项目进度阶段',
            references: {
                model: PrjPhaseDefine,
                key: 'id'
            }
        },
        type_id: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '客户行业分类id',
            references: {
                model: AcsDomain,
                key: 'id'
            }
        },
        customer_id: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '客户id',
            references: {
                model: BizCustomer,
                key: 'id'
            }
        },
        contract_id: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '合同id',
            references: {
                model: BizContractInfo,
                key: 'id'
            }
        },
        bizman_id: {
            type: DataTypes.STRING,
            allowNull: true,
            comment: '商务负责人账号id',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        leader_id: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '项目负责人账号id',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        intro: {
            type: DataTypes.TEXT,
            allowNull: true,
            comment: '项目简介'
        },
        created_at: {
            type: DataTypes.DATE,
            allowNull: false,
            comment: '创建时间',
            default: DataTypes.NOW
        },
        started_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '项目启动时间',
            default: DataTypes.NOW
        },
        updated_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '最近修改时间'
        },
        deliver_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '预计交付时间'
        },
        progress: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '进度百分比',
            defaultValue: 0
        },
        flow_case_id: {
            type: DataTypes.STRING(16),
            allowNull: false,
            comment: '工作流实例id'
        },
        checkers: {
            type: DataTypes.JSONB,
            allowNull: true,
            comment: '审批人列表'
        }
    }

    static indexes = [
        {fields: ['created_at']},
        {fields: ['name']}
    ]

    static associate(sequelize: Sequelize) {
        try {
            // AcsDomain.hasMany(BizCustomer, {foreignKey: 'region_id', sourceKey: 'id'});
            // BizCustomer.belongsTo(AcsDomain, {foreignKey: 'region_id', targetKey: 'id'});
            // BizCustomerLevel.hasMany(BizCustomer, {foreignKey: 'level_id', sourceKey: 'id'});
            // BizCustomer.belongsTo(BizCustomerLevel, {foreignKey: 'level_id', targetKey: 'id'});
            // BizCustomerIndustry.hasMany(BizCustomer, {foreignKey: 'industry_id', sourceKey: 'id'});
            // BizCustomer.belongsTo(BizCustomerIndustry, {foreignKey: 'industry_id', targetKey: 'id'});

            PrjInfo.belongsTo(AcsUserInfo, {foreignKey: 'leader_id', targetKey: 'id', as: 'PrjLeaderUserInfo'});
            AcsUserInfo.hasMany(PrjInfo, {foreignKey: 'leader_id', sourceKey: 'id'});
        } catch (e) {
            console.log(e);
        }
    }

    static init_sqls = [
    ]
}
