import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {AcsRole} from "@core-models/AcsRole";
import {PrjInfo} from "@core-models/PrjInfo";

/**
 * 项目成员表
 */

export class PrjMembers extends Model {
    // declare id: string;
    declare member_id: string;

    static table_name = 'tb_prj_members';

    static attributes = {
        prj_id: {
            type: DataTypes.STRING(16),
            primaryKey: true,
            comment: '项目编号',
            references: {
                model: PrjInfo,
                key: 'id'
            }
        },
        member_id: {
            type: DataTypes.STRING,
            primaryKey: true,
            allowNull: false,
            comment: '成员账号',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        draft: {
            type: DataTypes.BOOLEAN,
            primaryKey: true,
            allowNull: false,
            comment: '是否是副本',
            defaultValue: false
        },
        role_id: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '成员角色',
            references: {
                model: AcsRole,
                key: 'id'
            }
        },
        memo: {
            type: DataTypes.TEXT,
            allowNull: true,
            comment: '说明'
        },
        created_at: {
            type: DataTypes.DATE,
            allowNull: false,
            comment: '创建时间',
            default: DataTypes.NOW
        },
        updated_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '最近修改时间'
        }

    }

    static indexes = [
        {fields: ['created_at']},
        {fields: ['member_id']},
        {fields: ['role_id']},
        {fields: ['member_id', 'role_id']},
    ]

    static associate(sequelize: Sequelize) {
        try {
            // AcsDomain.hasMany(BizCustomer, {foreignKey: 'region_id', sourceKey: 'id'});
            // BizCustomer.belongsTo(AcsDomain, {foreignKey: 'region_id', targetKey: 'id'});
            // BizCustomerLevel.hasMany(BizCustomer, {foreignKey: 'level_id', sourceKey: 'id'});
            // BizCustomer.belongsTo(BizCustomerLevel, {foreignKey: 'level_id', targetKey: 'id'});
            // BizCustomerIndustry.hasMany(BizCustomer, {foreignKey: 'industry_id', sourceKey: 'id'});
            // BizCustomer.belongsTo(BizCustomerIndustry, {foreignKey: 'industry_id', targetKey: 'id'});
            PrjMembers.belongsTo(AcsUserInfo, {foreignKey: 'member_id', targetKey: 'id', as: 'PrjMemberUserInfo'});
            AcsUserInfo.hasMany(PrjMembers, {foreignKey: 'member_id', sourceKey: 'id'});
        } catch (e) {
            console.log(e);
        }
    }

    static init_sqls = [
    ]
}
