import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';

/**
 * 项目进度定义表
 */

export class PrjPhaseDefine extends Model {
    declare id: string;
    declare name: string;
    declare order_index: number;

    static table_name = 'tb_prj_phase_define';

    static attributes = {
        id: {
            type: DataTypes.STRING(16),
            primaryKey: true,
            comment: '项目进度阶段编号',
        },
        name: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '项目阶段名称',
        },
        color: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '项目阶段标签颜色',
            defaultValue: 'gray'
        },
        order_index: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '流程顺序号'
        }
    }

    static indexes = [

    ]

    static associate(sequelize: Sequelize) {

    }

    static init_sqls = [
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('new', '新建', 'pinkpurple', 0) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('reject_create', '立项被驳回', 'red', 0) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('apply_create', '申请立项中', 'gold', 10) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('overview_create', '立项审核中', 'gold', 15) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('created', '已立项', 'cyan', 20) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('reject_plan', '计划被驳回', 'orange', 25) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('apply_plan', '计划已提交', 'green', 30) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('overview_plan', '计划审核中', 'arcoblue', 40) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('apply_plan_alt', '计划变更已提交', 'green', 60) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('review_plan_alt', '计划变更审核中', 'orange', 65) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('reject_plan_alt', '计划变更被驳回', 'red', 70) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('doing', '执行中', 'arcoblue', 70) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('checking', '验收中', 'blue', 80) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('done', '已完成', 'green', 100) ON CONFLICT DO NOTHING; `,
        `insert into ${PrjPhaseDefine.table_name} (id, name, color, order_index) values ('deprecated', '已作废', 'gray', 90) ON CONFLICT DO NOTHING; `
    ]
}
