import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {PrjInfo} from "@core-models/PrjInfo";

/**
 * 项目计划任务表
 */

export class PrjPlanTaskDraft extends Model {
    declare id: string;
    declare pid: string;
    declare status: number;
    declare prj_id: string;
    declare begin_at: string;
    declare end_at: string;
    declare progress: number;
    declare draft: boolean;
    declare org_task_id: string;
    declare created_at: string;
    declare version: number;
    declare change_marker: number;
    declare checkers: any;
    declare handler_id: string;

    static table_name = 'tb_prj_plan_task_draft';

    static attributes = {
        id: {
            type: DataTypes.STRING(16),
            primaryKey: true,
            comment: '编号'
        },
        version: {
            type: DataTypes.INTEGER,
            primaryKey: true,
            allowNull: false,
            comment: '版本',
            defaultValue: 0
        },
        // draft_published: {
        //     type: DataTypes.BOOLEAN,
        //     primaryKey: true,
        //     comment: '草稿是否已审核后正式发布',
        //     defaultValue: false
        // },
        name: {
            type: DataTypes.STRING,
            comment: '名称'
        },
        pid: {
            type: DataTypes.STRING(16),
            comment: '父任务id',
            allowNull: true,
            defaultValue: null,
            // references: {
            //     model: PrjPlanTaskDraft,
            //     key: 'id'
            // }
        },
        prj_id: {
            type: DataTypes.STRING(16),
            comment: '项目编号',
            references: {
                model: PrjInfo,
                key: 'id'
            }
        },
        progress: {
            type: DataTypes.INTEGER,
            comment: '进度百分比',
            defaultValue: 0,
        },
        status: {
            type: DataTypes.INTEGER,
            comment: '状态',
            defaultValue: 0,
        },
        handler_id: {
            type: DataTypes.STRING,
            comment: '负责人账号',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        creator_id: {
            type: DataTypes.STRING,
            comment: '创建人账号',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        begin_at: {
            type: DataTypes.DATE,
            allowNull: false,
            comment: '计划开始时间（YYYY-MM-DD）',
        },
        end_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '计划结束时间（YYYY-MM-DD）'
        },
        completed_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '任务完成时间（YYYY-MM-DD）'
        },
        created_at: {
            type: DataTypes.DATE,
            allowNull: false,
            comment: '创建时间',
            default: DataTypes.NOW
        },
        updated_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '最近修改时间'
        },
        description: {
            type: DataTypes.TEXT,
            allowNull: true,
            comment: '任务描述'
        },
        order_id: {
            type: DataTypes.STRING(16),
            allowNull: false,
            defaultValue: "0",
            comment: '任务排序编号（从小到大排序）'
        },
        change_marker: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '变动标记，0=没有变动，1=已修改，2=新增，3=已删除',
            defaultValue: 0
        },
        checkers: { // 数据结构为Array<IChecker>
            type: DataTypes.JSONB,
            allowNull: true,
            comment: '审核人及动作定义',
            defaultValue: []
        }

    }

    static indexes = [
        // {fields: ['created_at']},
    ]

    static associate(sequelize: Sequelize) {
        try {
        } catch (e) {
            console.log(e);
        }
    }

    static init_sqls = [
    ]
}
