import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {PrjPlanTask} from "@core-models/PrjPlanTask";
import {PrjPlanTaskDraft} from "@core-models/PrjPlanTaskDraft";

/**
 * 项目计划任务项交付物草稿表
 */

export class PrjTaskOutcomeDraft extends Model {
    declare id: string;
    declare status: number;
    declare task_id: string;
    declare uploaded: boolean;
    declare change_marker: number;

    static table_name = 'tb_prj_task_outcome_draft';

    static attributes = {
        id: {
            type: DataTypes.STRING(16),
            primaryKey: true,
            comment: '编号'
        },
        version: {
            type: DataTypes.INTEGER,
            primaryKey: true,
            allowNull: false,
            comment: '版本',
            defaultValue: 0
        },
        // draft_published: {
        //     type: DataTypes.BOOLEAN,
        //     primaryKey: true,
        //     comment: '草稿是否已审核后正式发布',
        //     defaultValue: false
        // },
        name: {
            type: DataTypes.STRING,
            comment: '名称'
        },
        task_id: {
            type: DataTypes.STRING(16),
            comment: '任务编号'
        },
        // draft: {
        //     type: DataTypes.BOOLEAN,
        //     allowNull: false,
        //     comment: '是否是副本',
        //     defaultValue: false,
        //     // references: {
        //     //     model: PrjPlanTask,
        //     //     key: 'draft'
        //     // }
        // },
        status: {
            type: DataTypes.INTEGER,
            comment: '0=未交付、10=申请审核中，20=审核中、30=审核未通过、100=已完成交付。默认为0',
            defaultValue: 0,
        },
        creator_id: {
            type: DataTypes.STRING,
            comment: '创建人账号',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        plan_time: {
            type: DataTypes.DATE,
            allowNull: false,
            comment: '计划交付时间（YYYY-MM-DD）',
        },
        completed_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '实际交付时间（YYYY-MM-DD）'
        },
        created_at: {
            type: DataTypes.DATE,
            allowNull: false,
            comment: '创建时间',
            default: DataTypes.NOW
        },
        updated_at: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '最近修改时间'
        },
        description: {
            type: DataTypes.TEXT,
            allowNull: true,
            comment: '任务描述'
        },
        order_id: {
            type: DataTypes.STRING(16),
            allowNull: false,
            defaultValue: "0000000000000000",
            comment: '排序编号（从小到大排序）'
        },
        // object_name: {
        //     type: DataTypes.STRING,
        //     allowNull: true,
        //     comment: 'oss中保存的object name'
        // },
        // filename: {
        //     type: DataTypes.STRING,
        //     allowNull: true,
        //     comment: '文件的原始文件名'
        // },
        uploaded: {
            type: DataTypes.BOOLEAN,
            allowNull: false,
            defaultValue: false,
            comment: '是否已上传'
        },
        change_marker: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '变动标记，0=没有变动，1=已修改，2=新增，3=已删除',
            defaultValue: 0
        }

    }

    static indexes = [
        // {fields: ['created_at']},
    ]

    static associate(sequelize: Sequelize) {
        try {
            // PrjTaskOutcome.belongsTo(PrjPlanTask, { foreignKey: ['task_id', 'draft'], targetKey: ['task_id', 'draft'], as: 'PrjTaskOutcome_task' });
            // PrjPlanTask.hasOne(PrjTaskOutcome, { foreignKey: ['task_id', 'draft'], sourceKey: ['task_id', 'draft'], as: 'PrjPlanTask_outcome' });
        } catch (e) {
            console.log(e);
        }
    }

    static init_sqls = [
    ]
}
