import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {PrjInfo} from "./PrjInfo";

/**
 * 项目周报表
 */

export class PrjWeekReport extends Model {
    declare id: string;
    declare created_at: string;
    declare status: number;
    declare reporter_id: string;
    declare prj_id: string;

    static table_name = 'tb_prj_week_report';

    static attributes = {
        id: {
            type: DataTypes.STRING(16),
            primaryKey: true,
            comment: '编号',
        },
        prj_id: {
            type: DataTypes.STRING(16),
            allowNull: false,
            comment: '项目编号',
            references: {
                model: PrjInfo,
                key: 'id'
            }
        },
        created_at: {
            type: DataTypes.DATE,
            allowNull: false,
            comment: '创建时间',
            defaultValue: DataTypes.NOW
        },
        reporter_id: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '填报人账号id',
            references: {
                model: AcsUserInfo,
                key: 'id'
            }
        },
        summary: {
            type: DataTypes.TEXT,
            allowNull: false,
            comment: '本周总结'
        },
        plan: {
            type: DataTypes.TEXT,
            allowNull: false,
            comment: '下周计划'
        },
        issue: {
            type: DataTypes.TEXT,
            allowNull: true,
            comment: '需要协调的问题'
        },
        year: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '年份'
        },
        month: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '月份'
        },
        week: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '本年度第几周'
        },
        begin_from: {
            type: DataTypes.DATEONLY,
            allowNull: false,
            comment: '周一日期'
        },
        end_to: {
            type:DataTypes.DATEONLY,
            allowNull: false,
            comment: '周日日期'
        },
        status: {
            type: DataTypes.INTEGER,
            allowNull: false,
            comment: '周报状态：0=起草，20=提交，30=撤回，40=驳回，100=已审阅',
            defaultValue: 0
        }
    }

    static indexes = [

    ]

    static associate(sequelize: Sequelize) {

    }

    static init_sqls = [

    ]
}
