import {Model} from "sequelize";
import { Sequelize, DataTypes }  from 'sequelize';
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {PrjWeekReport} from "./PrjWeekReport";

/**
 * 项目周报附件表
 */

export class PrjWeekReportAttachment extends Model {
    declare id: string;
    declare object_name: string;
    declare filename: string;
    declare uploaded_at: string;

    static table_name = 'tb_prj_week_report_attachment';

    static attributes = {
        id: {
            type: DataTypes.STRING(16),
            primaryKey: true,
            comment: '编号',
        },
        report_id: {
            type: DataTypes.STRING(16),
            allowNull: false,
            comment: '周报id',
            references: {
                model: PrjWeekReport,
                key: 'id'
            }
        },
        uploaded: {
            type: DataTypes.BOOLEAN,
            allowNull: false,
            defaultValue: false,
            comment: '申请上传地址后，有没有真正上传'
        },
        req_upload_time: {
            type: DataTypes.DATE,
            allowNull: true,
            comment: '请求获取上传url时间'
        },
        uploaded_at: {
            type: DataTypes.DATE,
            allowNull: false,
            comment: '上传完成时间',
            defaultValue: DataTypes.NOW
        },
        object_name: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: 'oss object name'
        },
        filename: {
            type: DataTypes.STRING,
            allowNull: false,
            comment: '附件原始文件'
        }
    }

    static indexes = [

    ]

    static associate(sequelize: Sequelize) {

    }

    static init_sqls = [

    ]
}
