import {MicroSvr} from "@core/MicroSvr";
import {Config, IConfig, IDatabaseConfig} from "@util/Config";
import {RouterBase} from "@core/Router";
import {Logger} from "@util/Logger";
import {init_infrastructure} from "@core/Infrastructure";
import {IDataModelInfo, init_data_models} from "@core/InitDataModel";

export class ServiceApp {
    private micro_svr?: MicroSvr;
    private readonly config_file?: string;
    private config_params: IConfig;
    private force_async_db: boolean = false;

    constructor(config_file?: string) {
        this.config_file = config_file;
    }

    async start(router: RouterBase, models: Array<IDataModelInfo>, port?: number, force_async_db?: boolean) {
        let params = Config.params(this.config_file);
        this.config_params = params;
        Logger.info('starting...');
        await init_infrastructure();
        Logger.service_name = params.name;
        Logger.log_level = params.log_level !== undefined ? params.log_level : 2;
        this.force_async_db = force_async_db ? force_async_db : false;

        for (let i = 0; params.infrastructure?.db && i < params.infrastructure.db.length; i++) {
            let db_config: IDatabaseConfig = params.infrastructure.db[i];
            await init_data_models(db_config.id, models, force_async_db);
        }

        this.micro_svr = new MicroSvr({
            router: router,
            port: port
        });
        Logger.info('started');
    }

    stopSvr() {
        this.micro_svr?.stop();
    }

    get app() {
        return this.micro_svr?.app;
    }

    // only for test
    async init_data_models(models: Array<IDataModelInfo>){
        if (process.env.TEST !== 'true') return;
        for (let i = 0; this.config_params.infrastructure?.db && i < this.config_params.infrastructure.db.length; i++) {
            let db_config: IDatabaseConfig = this.config_params.infrastructure.db[i];
            await init_data_models(db_config.id, models, this.force_async_db);
        }
    }

}
