/**
 * 用于获取基础服务接口，包括数据库、Redis、Kafka、MQTT等
 */
import {
    Config,
    IDatabaseConfig,
    IKafkaConfig,
    IMongodbConfig,
    IOssConfig,
    IRedisConfig,
    IRelationServiceConfig, IWssConfig
} from "@util/Config";
import {Orm} from "@util/Orm";
import {Redis} from "@util/Redis";
import {Kafka} from "@util/Kafka";
import {Oss} from "@util/Oss";
import {IdGen} from "@util/IdGen";
import Mongo from "@util/mongodb/Mongo";
import {Services} from "@util/Services";
import {Logger} from "@util/Logger";
import {WsService} from "@util/WsService";

export function init_infrastructure(): Promise<void> {
    return new Promise<void>(async (resolve, reject) => {
        try {
            let config = Config.params();
            IdGen.init(config.id);
            if (!config.infrastructure) return resolve();
            for (let i = 0; config.infrastructure.db && i < config.infrastructure.db.length; i++) {
                let dbConfig: IDatabaseConfig = config.infrastructure.db[i];
                await Orm.init_instance(dbConfig.id, dbConfig);
            }

            for (let i = 0; config.infrastructure.redis && i < config.infrastructure.redis.length; i++) {
                let redis: IRedisConfig = config.infrastructure.redis[i];
                await Redis.init_instance(redis.id, redis);
            }

            for (let i = 0; config.infrastructure.kafka && i < config.infrastructure.kafka.length; i++) {
                let kafka: IKafkaConfig = config.infrastructure.kafka[i];
                Kafka.init_instance(kafka.id, kafka);
            }

            for (let i = 0; config.infrastructure.mongodb && i < config.infrastructure.mongodb.length; i++) {
                let mongodb: IMongodbConfig = config.infrastructure.mongodb[i];
                await Mongo.initInstance(mongodb.tag, mongodb);
            }

            for (let i = 0; config.infrastructure.oss && i < config.infrastructure.oss.length; i++) {
                let oss: IOssConfig = config.infrastructure.oss[i];
                await Oss.init_instance(oss.id, oss);
            }

            for (let i = 0; config.infrastructure.wss && i < config.infrastructure.wss.length; i++) {
                let wss: IWssConfig = config.infrastructure.wss[i];
                await WsService.init_instance(wss.id, wss);
            }

            for (let i = 0; config.relations && i < config.relations.length; i++) {
                let service: IRelationServiceConfig = config.relations[i];
                Services.init_instance(service.name, service);
            }

            resolve();
        } catch (e) {
            reject(e);
        }

    })

}

export function orm<T>(id: T): Orm {
    return Orm.get_instance(<string><unknown>id);
}

export function redis<T>(id: T): Redis {
    return Redis.get_instance(<string><unknown>id);
}

export function kafka<T>(id: T): Kafka {
    return Kafka.get_instance(<string><unknown>id);
}

export function oss<T>(id: T): Oss {
    return Oss.get_instance(<string><unknown>id);
}
