import express = require('express');
import {Logger} from "@util/Logger";
import {Resp} from "@util/Resp";
import {Auditor} from "@core/Auditor";
import {apiGuards} from "@core-guards/apiGuards";
import {Proxy} from "@core/Proxy";
import * as fs from "fs";
import * as path from "path";
import {RouterBase} from "@core/Router";
import {IApiInfo} from "@core/Defined";

export class ProxyRouter extends RouterBase{
    protected auditor: Auditor;
    private proxy: Proxy;

    constructor() {
        super('', [] );
        this.auditor = new Auditor(apiGuards);
        let proxyTargets;
        if (process.env.NODE_ENV === 'development') {
            proxyTargets = JSON.parse(fs.readFileSync(path.join(process.cwd(), 'proxy_dev.json'), "utf-8"));
        } else {
            proxyTargets = JSON.parse(fs.readFileSync(path.join(process.cwd(), 'proxy.json'), "utf-8"));
        }
        this.proxy = new Proxy(proxyTargets);
    }

    private proxy_parser(path: string): IApiInfo {
        // 分析url路径，并生成路由路径
        if (path.charAt(0) === '/') path = path.slice(1, path.length); // 去除首个/符
        let pathArray: Array<string> = path.split('/');
        let api = pathArray[pathArray.length - 1];
        return {
            api: api,
        };
    }

    // public async route(req: express.Request, res: express.Response, next: any) {
    public async route(req: express.Request, res: express.Response, _next: any) {
        let json = req.body;
        json.__cachedData = {}
        let path = req.params[0];
        let apiInfo: IApiInfo = this.proxy_parser(path);
        Logger.trace(json, path);

        try {
            json.__cachedData = {
                from: req.ip,
                api: apiInfo.api
            };
            await this.auditor.proxy_audit(path, json, json.__cachedData);
            await this.proxy.route(req, res, apiInfo.api);
        } catch (e) {
            Resp.respond_err(apiInfo.api, res, e);
        }
    }
}
