export interface IKeyPairs {
    public_key: string;
    private_key: string;
}

export function gen_key_pairs(modulus_length: number): Promise<IKeyPairs> {
    return new Promise<IKeyPairs>(async (resolve, reject) => {
        try{
            const { generateKeyPair } = await import('crypto');
            generateKeyPair('rsa', {
                modulusLength: modulus_length,
                publicKeyEncoding: {
                    type: 'spki',
                    format: 'pem'
                },
                privateKeyEncoding: {
                    type: 'pkcs8',
                    format: 'pem'
                }
            }, (err: any, public_key: any, private_key: any) => {
                if (err) throw err;
                return resolve({
                    public_key: public_key,
                    private_key: private_key
                })
            })
        }catch (e) {
            reject(e);
        }
    })

}

export function escapeQuotes(value: any): string {
    if (value && typeof (value) === 'string') { // 保证value不是undefined并且是字符串类型
        value = value.replace(/\'/g, '\'\'');
        // 将所有的'转义成\'
    }
    return value;
}
