import * as crypto from 'crypto';
import _ from "lodash";
import * as path from 'path';
import {StringDecoder} from 'string_decoder';
import {EventEmitter} from 'events';
import * as url from 'url';
import {URL} from 'url';
import * as util from 'util';
import * as zlib from 'zlib';
import * as stream from 'stream';

export class SharedContext {
    public static data: any = {
        get Buffer() {
            return Buffer;
        },
        get Blob() {
            return Blob;
        },
        get console() {
            return console
        },
        get crypto() {
            return crypto
        },
        get Error() {
            return Error;
        },
        get EventEmitter() {
            return EventEmitter;
        },
        get path() {
            return path;
        },
        get StringDecoder() {
            return StringDecoder;
        },
        get setImmediate() {
            return setImmediate;
        },
        get setInterval() {
            return setInterval;
        },
        get setTimeout() {
            return setTimeout;
        },
        get clearImmediate() {
            return setImmediate;
        },
        get clearInterval() {
            return setTimeout;
        },
        get clearTimeout() {
            return setInterval;
        },
        get url() {
            return url;
        },
        get URL() {
            return URL;
        },
        get util() {
            return util;
        },
        get zlib() {
            return zlib;
        },
        get stream() {
            return stream;
        },
        get Math() {
            return Math
        },
        get Date() {
            return Date
        },
        get Array() {
            return Array
        },
        get RegExp() {
            return RegExp
        },
        get parseInt() {
            return parseInt
        },
        get JSON() {
            return JSON
        },
        get eval() {
            return eval;
        },
        get Promise() {
            return Promise
        },

    };
}

export interface ISandboxData {
    global?: any;
    data?: any;
    context?: any;
}

export function evaluate(code: string, sandbox_data?: ISandboxData): any {
    let sandbox = SharedContext.data;
    const fn = new Function('sandbox', `with(sandbox){ \n return eval(\`(()=>{let __$$ = ${code}; \n return __$$;})()\`); \n}`);
    // const fn = new Function('sandbox', `with(sandbox){let xxxx = \`(()=>{let x = ${code}; \n return x;})()\`;\n debugger; \n return eval(\`(()=>{\n debugger; \nlet x = ${code}; \n console.log(typeof ${code});\n debugger; \n return x;})()\`); \n}`);
    const proxy = new Proxy(sandbox, {
        has(_target, _key) {
            // 让动态执行的代码认为属性已存在，于是不再向上冒泡，使执行的表达式的上下文限制在沙盒内
            return true;
        },
        get(target, property: string | symbol) {
            if (typeof property === 'string') {
                let result = sandbox[property];
                if (result === undefined && sandbox_data) {
                    result = (sandbox_data.global ? sandbox_data.global[property] : undefined);
                      // || (sandbox_data.data ? sandbox_data.data[property] : undefined)
                      // || (sandbox_data.context ? sandbox_data.context[property] : undefined);
                    if (typeof result === 'string') {   // 要将result的"转义成\"
                        result = result.replace(/"/g, "\\\"").replace(/'/g, "\\\'").replace(/`/g, "\\\`");
                    } else if (typeof result === 'object') {
                        // 防止出现替换成[object, Object]这种情况，将toString替换成JSON.stringify
                        let proxy = result.toString;
                        result.toString = new Proxy(proxy, {
                            apply: (_target, _thisArg, _argumentsList) => {
                                return JSON.stringify(result);
                            }
                        });
                    } else if (typeof result === 'function') {
                        result = result();
                    }
                }
                return result;
            }
        }
    });
    return fn(proxy);
}


export function executor(expression: any, data?: ISandboxData): any {
    let result;
    if (typeof expression === 'string') {
        result = evaluate(expression, data);
    } else if (typeof expression === 'number' || typeof expression === 'boolean') {
        result = expression;
    } else if (typeof expression === 'function') {
        result = evaluate(expression, data);
    } else {
        result = evaluate(JSON.stringify(_.cloneDeep(expression)), data);
    }
    return result;
}
