import {clone} from "@util/JsonToolkit";

enum ELogLevel {
    NULL,
    ERROR,
    INFO,
    DEBUG,
    TRACE,
    ALL
}

export class Logger {
    static log_level: number = ELogLevel.ALL;
    static service_name: string = '';

    static stack_info(stack_depth?: number): any {
        let depth = stack_depth ? stack_depth : 2;
        let path = require('path');
        let stack_reg = /at\s+(.*)\s+\((.*):(\d*):(\d*)\)/i;
        let info_reg = /at\s+(.*):(\d*):(\d*)/i;
        let err = new Error();
        if (!err.stack) return '';
        let stack_list = err.stack.split('\n').slice(3);
        if (!stack_list) return '';
        let s = stack_list[depth];
        let sp = stack_reg.exec(s) || info_reg.exec(s);
        let data: any = {};
        if (sp && sp.length >= 4) {
            data.path = sp.length === 5 ? sp[2] : sp[1];
            data.line = sp.length === 5 ? sp[3] : sp[2];
            data.pos = sp.length === 5 ? sp[4] : sp[3];
            data.file = path.basename(data.path);
        }

        return data;
    }

    static track_str(): string {
        let info = Logger.stack_info();
        let file = info['file'];
        let line = info['line'];

        return `<${file}:${line}> `;
    }

    static simplify(content: any) {
        for (let key in content) {
            if (!Object.hasOwnProperty.call(content, key)) {
                continue;
            }

            if (typeof content[key] === 'object') {
                Logger.simplify(content[key]);
            } else if (typeof content[key] === 'string') {
                if (content[key].length > 512) {
                    content[key] = content[key].substring(0, 512) + '...';
                }
            }
        }
    }

    static log(content: any, level?: number, tag?: string) {
        if (level === undefined) {
            level = ELogLevel.INFO;
        }
        if (level > Logger.log_level) return;
        if (tag === undefined) tag = '';
        else tag = `(${tag})`;
        let log_info = content;
        if (typeof content === 'object') {
            log_info = clone(content);
            Logger.simplify(log_info);
        } else if (typeof content === 'string' && content.length > 256) {
            log_info = content.substring(0, 256) + '...';
        }
        let level_tag = '';
        switch (level) {
            case ELogLevel.ERROR:
                level_tag = '\x1b[31m[ERROR]';
                break;
            case ELogLevel.INFO:
                level_tag = '\x1b[32m[INFO]';
                break;
            case ELogLevel.DEBUG:
                level_tag = '\x1b[34m[DEBUG]';
                break;
            case ELogLevel.TRACE:
                level_tag = '\x1b[90m[TRACE]';
                break;
        }
        if (typeof content === 'object') {
            console.log(`\x1b[37m${new Date().toISOString()} ${level_tag} ${Logger.service_name} ${Logger.track_str()} ${tag} -------->`);
            console.log(log_info);
            console.log('<---------------------------');
        } else {
            console.log(`\x1b[37m${new Date().toISOString()} ${level_tag} ${Logger.service_name} ${Logger.track_str()} ${tag}: ${log_info}`);
        }
    }

    static debug(context: any, tag?: string) {
        Logger.log(context, ELogLevel.DEBUG, tag);
    }

    static info(context: any, tag?: string) {
        Logger.log(context, ELogLevel.INFO, tag);
    }

    static error(context: any, tag?: string) {
        Logger.log(context, ELogLevel.ERROR, tag);
    }

    static trace(context: any, tag?: string) {
        Logger.log(context, ELogLevel.TRACE, tag);
    }
}
