import { Model, Connection } from 'mongoose';
import MongoClient from './mongodb';
import { IMongodbConfig } from "@util/Config";
import {Resp} from "@util/Resp";

export default class Mongo {
    static instanceMap: Map<string, Mongo> = new Map<string, Mongo>();
    private model: Model<any>;
    private mongoClient: Connection //& Promise<Connection>;

    static async initInstance(tag: string, config: IMongodbConfig): Promise<Mongo> {
        return new Promise<Mongo>(async (resolve, reject) => {
            let instance = Mongo.instanceMap.get(tag);
            if (!instance) {
                instance = new Mongo(tag, config);
            }
            return resolve(instance);
        })
    }

    static getInstance(tag: string): Connection {
        let instance = Mongo.instanceMap.get(tag);
        if (!instance) {
            // throw new Error(`Mongo ${tag} should be init.`);
            throw Resp.gen_err(Resp.InternalServerError, `mongo db "${tag}" should be init.`);
        }
        return instance.mongoClient;
    }

    constructor(tag: string, config: IMongodbConfig) {
        try{
            this.mongoClient = new MongoClient(config).mongoClient;
            Mongo.instanceMap.set(tag, this);
        }catch(err){
            console.log(err)
        }

    }

}

