import { Model, Connection } from 'mongoose';

export class BaseDao {
    public Model: any;
    /**
     * 子类构造传入对应的 Model 类
     *
     * @param Model
     */
    constructor(Model: Model<any>) {
        this.Model = Model;
    }


    /**
     * 使用 Model 的 静态方法 create() 添加 doc
     *
     * @param obj 构造实体的对象
     * @returns {Promise}
     */
    public create(obj: any) {
        return new Promise((resolve, reject) => {
            obj = JSON.parse(JSON.stringify(obj));
            let entity = new this.Model(obj);
            this.Model.create(entity, (error: any, result: any) => {
                if (error) {
                    // console.log('create error--> ', error);
                    reject(error);
                } else {
                    // console.log('create result--> ', JSON.stringify(result));
                    resolve(result)
                }
            });
        });
    }


    /**
     * 使用 Model save() 添加 doc
     *
     * @param obj 构造实体的对象
     * @returns {Promise}
     */
    public save(obj: any) {
        return new Promise((resolve, reject) => {
            let entity = new this.Model(obj);
            entity.save((error: any, result: any) => {
                if (error) {
                    console.log('save error--> ', error);
                    reject(error);
                } else {
                    //   console.log('save result--> ', result);
                    resolve(result)
                }
            });
        });
    }


    /**
     * 查询所有符合条件 docs
     *
     * @param condition 查找条件
     * @param constraints
     * @returns {Promise}
     */
    public findAllAndCount(condition: any, constraints: any, options:any):Promise<{count:number, results:Array<any>}> {
        return new Promise((resolve, reject) => {
            this.Model.find(condition, constraints ? constraints : null, options, (error: any, results: any) => {
                if (error) {
                    console.log('findAll error--> ', error);
                    reject(error);
                } else {
                    //   console.log('findAll results--> ', results);
                    this.Model.count(condition, (error: any, count: any) => {
                        if (error) {
                            console.log('findAll error--> ', error);
                            reject(error);
                        } else {
                            resolve({count,results});
                        }
                    })
                }
            });
        });
    }

    /**
     * 查询所有符合条件 docs
     *
     * @param condition 查找条件
     * @param constraints
     * @returns {Promise}
     */
     public findAll(condition: any, constraints: any) {
        return new Promise((resolve, reject) => {
            this.Model.find(condition, constraints ? constraints : null, (error: any, results: any) => {
                if (error) {
                    console.log('findAll error--> ', error);
                    reject(error);
                } else {
                    resolve(results);
                }
            });
        });
    }


    /**
     * 查找符合条件的第一条 doc
     *
     * @param condition
     * @param constraints
     * @returns {Promise}
     */
    public findOne(condition: any, constraints: any) {
        return new Promise((resolve, reject) => {
            this.Model.findOne(condition, constraints ? constraints : null, (error: any, results: any) => {
                if (error) {
                    console.log('findOne error--> ', error);
                    reject(error);
                } else {
                    //   console.log('findOne results--> ', results);
                    resolve(results);
                }
            });
        });
    }


    /**
     * 查找排序之后的第一条
     *
     * @param condition
     * @param orderColumn
     * @param orderType
     * @returns {Promise}
     */
    public findOneByOrder(condition: any, orderColumn: any, orderType: any) {
        return new Promise((resolve, reject) => {
            this.Model.findOne(condition)
                .sort({
                    [orderColumn]: orderType
                })
                .exec(function (err: any, record: any) {
                    console.log(record);
                    if (err) {
                        reject(err);
                    } else {
                        resolve(record);
                    }
                });
        });
    }


    /**
     * 更新 docs
     *
     * @param condition 查找条件
     * @param updater 更新操作
     * @returns {Promise}
     */
    public update(condition: any, updater: any) {
        return new Promise((resolve, reject) => {
            this.Model.update(condition, updater, (error: any, results: any) => {
                if (error) {
                    console.log('update error--> ', error);
                    reject(error);
                } else {
                    //   console.log('update results--> ', results);
                    resolve(results);
                }
            });
        });
    }


    /**
     * 移除 doc
     *
     * @param condition 查找条件
     * @returns {Promise}
     */
    public remove(condition: any) {
        return new Promise((resolve, reject) => {
            this.Model.remove(condition, (error: any, result: any) => {
                if (error) {
                    console.log('remove error--> ', error);
                    reject(error);
                } else {
                    console.log('remove result--> ', result);
                    resolve(result);
                }
            });
        });
    }
}

export class ModelDao extends BaseDao {
    constructor(model: Model<any>) {
        super(model)
    }
}