import {Resp} from "@util/Resp";
import {ADMINISTRATOR, ICachedData, IRequest} from "@core/Defined";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {QueryTypes} from "sequelize";
import {AcsDomain} from "@core-models/AcsDomain";
import {AcsUserDomain} from "@core-models/AcsUserDomain";
import {escapeQuotes} from "@util/CryptTool";


export function subAccountGuard(json: IRequest, cached_data: ICachedData): Promise<void> {
    return new Promise<void>(async (resolve, reject) => {
        let user = cached_data.user_id;
        let data: any = json.data;
        if (!user) return reject(Resp.gen_err(Resp.Forbidden));
        if (user === ADMINISTRATOR) return resolve();
        if (!data.user_id) return resolve();
        let id = data.user_id.toLowerCase();
        if (id === undefined) return reject(Resp.gen_err(Resp.ParamsError, 'should have required property \'user_id\''));
        try {
            let sql = `select ${AcsDomain.table_name}.id, ${AcsDomain.table_name}.path 
                    from ${AcsUserDomain.table_name},${AcsDomain.tableName}
                       where ${AcsDomain.tableName}.id = ${AcsUserDomain.tableName}.domain_id and 
                    ${AcsUserDomain.tableName}.user_id = :user`;
            let result = await AcsUserInfo.sequelize!.query(sql, {type: QueryTypes.SELECT, raw: true, replacements: {user: user}});
            if (result.length < 1) {
                return reject(Resp.gen_err(Resp.Forbidden, `${user}:${id} check sub account`));
            }

            let domain_ids = [];
            let domain_paths = [];
            for (let i = 0; i < result.length; i++) {
                // @ts-ignore
                domain_ids.push(result[i].id);
                // @ts-ignore
                domain_paths.push(result[i].path);
            }
            sql = `select ${AcsUserInfo.tableName}.id from ${AcsUserDomain.tableName},
                                                           ${AcsDomain.tableName},${AcsUserInfo.tableName}
                   where  (${AcsUserDomain.tableName}.domain_id = ${AcsDomain.tableName}.id and
                           ${AcsUserDomain.tableName}.user_id = ${AcsUserInfo.tableName}.id and (`;
            for (let i = 0; i < domain_paths.length; i++) {
                if (i > 0) {
                    sql += ' or ';
                }
                sql += ` (${AcsDomain.tableName}.path <@ '${escapeQuotes(domain_paths[i])}' )`;
            }
            sql += '))';

            sql += ` and ${AcsUserDomain.tableName}.user_id = '${escapeQuotes(id)}'`;
            let rows = await AcsUserInfo.sequelize!.query(sql, {type: QueryTypes.SELECT, raw: true});
            if (rows.length < 1) {
                return reject(Resp.gen_err(Resp.Forbidden, `${user}:${id} check sub account`));
            }
            resolve();
        } catch (e) {
            reject(e);
        }
    });
}
