import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import DataCURD from "@core/DataCURD";
import {AcsApplication} from "@core-models/AcsApplication";

interface IData {
    id: string;
}
function get_where(json: IRequest, _params: IMethodParams, _cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let data = <IData>json.data;
            resolve({app_id: data.id});
        } catch (e) {
            reject(e);
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "title": "修改应用信息",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "id": {
                        "type": "string",
                        "title": "application的app_Id"
                    },
                    "app_key": {
                        "type": "string",
                        "title": "application的app_key"
                    },
                    "name": {
                        "type": "string",
                        "title": "名称"
                    },
                    "app_type": {
                        "type": "integer",
                        "title": "类型，0=内部微服务 1=微信小程序，2=支付宝小程序，3=web客户端，4=设备端，5=第三方平台",
                        "enum": [0, 1, 2, 3, 4, 5]
                    },
                    "auth_type": {
                        "type": "integer",
                        "title": "认证方式：1=仅账号密码 2=账号密码+签名 3=仅签名",
                        "enum": [1, 2, 3]
                    },
                    "private_key": {
                        "type": "string",
                        "title": "pem格式私钥证书"
                    },
                    "public_key": {
                        "type": "string",
                        "title": "pem格式公钥证书"
                    },
                    "status": {
                        "type": "integer",
                        "title": "应用状态，1=正常，2=锁定"
                    },
                    "pay_key": {
                        "type": "string",
                        "title": "用于支付的key"
                    },
                    "mch_id": {
                        "type": "string",
                        "title": "商户号"
                    },
                    "api_cert_serial_no": {
                        "type": "string",
                        "title": "支付签名证书序列号"
                    },
                    "memo": {
                        "type": "string",
                        "title": "备注"
                    }
                },
                "required": [
                    "id",
                ],
                "anyOf": [
                    {"required": ["name"]},
                    {"required": ["app_key"]},
                    {"required": ["app_type"]},
                    {"required": ["auth_type"]},
                    {"required": ["private_key"]},
                    {"required": ["public_key"]},
                    {"required": ["status"]},
                    {"required": ["pay_key"]},
                    {"required": ["mch_id"]},
                    {"required": ["api_cert_serial_no"]},
                    {"required": ["memo"]}
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp",
            "data",
        ]
    },
    method: DataCURD.internal_update_row,
    method_params: {
        model: AcsApplication,
        where: get_where,
        input_data_map: {
            id: 'id',
            name: 'name',
            app_key: 'app_key',
            app_type: 'app_type',
            auth_type: 'auth_type',
            private_key: 'private_key',
            public_key: 'public_key',
            status: 'status',
            pay_key: 'pay_key',
            mch_id: 'mch_id',
            api_cert_serial_no: 'api_cert_serial_no',
            memo: 'memo'
        }
    }
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
