import {ADMINISTRATOR, IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsFunction} from "@core-models/AcsFunction";
import {QueryTypes} from "sequelize";
import {Resp} from "@util/Resp";
import {AcsRoleFunction} from "@core-models/AcsRoleFunction";
import {AcsUserRole} from "@core-models/AcsUserRole";
import {ISQLReplacements} from "@core/DataCURD";

interface IData {
    module_id?: string;
}

function get_list(json: IRequest, param: IMethodParams, cached_data: ICachedData): Promise<unknown> {
    return new Promise<unknown>(async (resolve, reject) => {
        let params: IData = <IData>json.data;
        try {
            let result = await do_get_list(params, cached_data);
            resolve(result);
        } catch (e) {
            reject(e);
        }

    });
}

function do_get_list(params: IData, cached_data: ICachedData): Promise<unknown> {
    return new Promise<unknown>(async (resolve, reject) => {

        let user: string = cached_data.user_id;
        let sql: string;
        let replacements: ISQLReplacements = {};
        if (user == ADMINISTRATOR) {
            sql = `select array_to_json(array_agg(row_to_json(d))) 
                    from ( 
                    select id, tag, module_id, name, api, check_auth, rw 
                    from  ${AcsFunction.table_name}
                    where true `;
        } else {
            sql = `select array_to_json(array_agg(row_to_json(d))) 
               from ( 
                    select id, tag, module_id, name, api, check_auth, rw 
                    from ${AcsFunction.table_name} 
                    where id in 
                    (select func_id 
                    from ${AcsRoleFunction.table_name},${AcsUserRole.table_name} 
                    where user_id= :user_id and ${AcsRoleFunction.table_name}.role_id = ${AcsUserRole.table_name}.role_id) `;
            replacements.user_id = user;
        }
        if (params.module_id == undefined) {
            sql += ' order by id) as d';
        } else {
            sql += ` and ${AcsFunction.table_name}.module_id = ${params.module_id} order by id) as d`;
        }
        try {
            let records: any = await AcsFunction.sequelize!.query(sql, {type: QueryTypes.SELECT, raw: true, replacements: replacements});
            // @ts-ignore
            let list = records[0].array_to_json;
            if (!records || records.length <= 0 ||  list === null) {
                resolve({functions: []});
            }
            let res_json = {
                functions: list
            }
            resolve(res_json);
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "module_id": {
                        "type": "integer"
                    }
                }
            }
        },
        "required": [
            "ver", "app_id", "timestamp", "data"
        ]
    },
    method: get_list,
    method_params: {}
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
