import {AcsFunction} from "@core-models/AcsFunction";
import {QueryTypes} from "sequelize";
import {AcsModule} from "@core-models/AcsModule";
import {Resp} from "@util/Resp";
import {ADMINISTRATOR, IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsRoleFunction} from "@core-models/AcsRoleFunction";
import {AcsUserRole} from "@core-models/AcsUserRole";
import {AcsUserInfo} from "@core-models/AcsUserInfo";

interface IData {
    id: number;
    tag: string;
    name: string;
    check_auth: boolean;
    rw: number;
}

function modify(json: IRequest, param: IMethodParams, cached_data: ICachedData): Promise<unknown> {
    return new Promise<unknown>(async (resolve, reject) => {
        let params: IData = <IData>json.data;
        try {
            let parent_path = await get_parent_path(params);
            let result = await do_get_list(params, parent_path, cached_data);
            resolve(result);
        } catch (e) {
            reject(e);
        }

    });
}

function get_parent_path(params: IData): Promise<string> {
    return new Promise<string>(async (resolve, reject) => {
        try {
            let sql = `select tag from ${AcsModule.table_name} where path @>  
                    (select ${AcsModule.table_name}.path from ${AcsModule.table_name},${AcsFunction.table_name}
                     where ${AcsModule.table_name}.id = ${AcsFunction.table_name}.module_id and ${AcsFunction.table_name}.id=${params.id})
                       order by path`;

            // let result: QueryResult = await db.query(sql, values);
            let records = await AcsFunction.sequelize!.query(sql, {type: QueryTypes.SELECT, raw: true});
            if (!records || records.length <= 0) {
                return reject(Resp.gen_err(Resp.Forbidden));
            }
            let parent_path = '';
            for (let i = 0; i < records.length; i++) {
                parent_path = parent_path + (<AcsFunction>records[i]).tag + '.';
            }
            resolve(parent_path);
        } catch (e) {
            reject(e);
        }
    });
}

function do_get_list(params: IData, parent_path: string, cached_data: ICachedData): Promise<unknown> {
    return new Promise<unknown>(async (resolve, reject) => {
        let user: string = cached_data.user_id;
        let sql: string;
        if (user == ADMINISTRATOR) {
            sql = `update tb_acs_function 
              set name='${params.name}', 
                  check_auth=${params.check_auth}, 
                  rw=${params.rw} where id=${params.id}`;
        } else {
            sql = `update ${AcsFunction.table_name} set 
                        name='${params.name}', check_auth=${params.check_auth}
                        where id in ( 
                    select ${AcsRoleFunction.table_name}.func_id as id 
                    from ${AcsRoleFunction.table_name}, ${AcsUserRole.table_name}, ${AcsUserInfo.table_name}, ${AcsFunction.table_name}
                    where 
                    ${AcsUserInfo.table_name}.id = '${user}' and 
                    ${AcsUserInfo.table_name}.id = ${AcsUserRole.table_name}.user_id and 
                    ${AcsRoleFunction.table_name}.role_id = ${AcsUserRole.table_name}.role_id and 
                    ${AcsFunction.table_name}.id = ${AcsRoleFunction.table_name}.func_id AND 
                    ${AcsFunction.table_name}.id = ${params.id})`;
        }

        try {
            await AcsFunction.sequelize!.query(sql);
            resolve({});
        } catch (e) {
            reject(e);
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "id": {
                        "type": "number"
                    },
                    "name": {
                        "type": "string"
                    },
                    "check_auth": {
                        "type": "boolean"
                    },
                    "rw": {
                        "type": "integer"
                    }
                },
                "required": [
                    "id"
                ],
                "anyOf": [
                    {"required": ["name"]},
                    {"required": ["check_auth"]}
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp", "data"
        ]
    },
    method: modify,
    method_params:{}
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
