import {ADMINISTRATOR, IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsFunction} from "@core-models/AcsFunction";
import {Resp} from "@util/Resp";
import {AcsRoleFunction} from "@core-models/AcsRoleFunction";

interface IData {
    id: number;
}

function remove(json: IRequest, param: IMethodParams, cached_data: ICachedData): Promise<unknown> {
    return new Promise<unknown>(async (resolve, reject) => {
        let params: IData = <IData>json.data;
        try {
            let result = await do_remove(params, cached_data);
            resolve(result);
        } catch (e) {
            reject(e);
        }
    });
}

function do_remove(params: IData, cached_data: ICachedData): Promise<unknown> {
    return new Promise<unknown>(async (resolve, reject) => {
        let user = cached_data.user_id;
        if (user !== ADMINISTRATOR) return reject(Resp.gen_err(Resp.Forbidden, 'must administrator'));

        let t = await AcsFunction.sequelize!.transaction();
        try {
            await AcsRoleFunction.destroy({where: {func_id: params.id}, transaction: t});
            await AcsFunction.destroy({where: {id: params.id}, transaction: t});
            await t.commit();
            resolve({});
        } catch (e) {
            await t.rollback();
            reject(e);
        }
    })
}


const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "id": {
                        "type": "number"
                    }
                },
                "required": [
                    "id"
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp",
            "data"
        ]
    },
    method: remove,
    method_params: {
        model: AcsFunction
    }
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
