import {ADMINISTRATOR, IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsModule} from "@core-models/AcsModule";
import {QueryTypes} from "sequelize";
import {ISQLReplacements} from "@core/DataCURD";


export function get_tree(json: IRequest, param: IMethodParams, cached_data: ICachedData): Promise<unknown> {
    return new Promise<unknown>(async (resolve, reject) => {
        let user = cached_data.user_id;
        try {
            let sql;
            // let values = [];
            let replacements: ISQLReplacements = {}
            if (user === ADMINISTRATOR) {
                sql = 'select id, tag, name, memo, pid, ui_show, path, nlevel(path) from tb_acs_module order by path';
            } else {
                sql = `select DISTINCT  tb_acs_module.id, tb_acs_module.tag, tb_acs_module.name, tb_acs_module.memo,
                            tb_acs_module.pid, 
                            tb_acs_module.ui_show, tb_acs_module.path, nlevel(tb_acs_module.path)
                    from tb_acs_role_function, tb_acs_user_role, tb_acs_function, tb_acs_module 
                    where tb_acs_role_function.role_id = tb_acs_user_role.role_id 
                    and tb_acs_function.module_id = tb_acs_module.id 
                    and tb_acs_function.id = tb_acs_role_function.func_id 
                    and tb_acs_user_role.user_id = :user_id
                    order by path;`;
                // values.push(user);
                replacements.user_id = user;
            }

            let result = await AcsModule.sequelize!.query(sql, {type: QueryTypes.SELECT, raw: true, replacements: replacements});
            let res = await do_build_tree(result);
            resolve(res);
        } catch (e) {
            reject(e);
        }
    });
}

function do_build_tree(records: Array<any>): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        let paths: Array<string> = [];
        for (let i = 0; i < records.length; i++) {
            paths.push(records[i].path);
        }
        let where_str = ' where (';
        for (let i = 0; i < paths.length; i++) {
            if (i == 0) {
                where_str += ' path ~ \'' + paths[i] + '.*\'';
            } else {
                where_str += ' or path ~ \'' + paths[i] + '.*\'';
            }
            where_str += ' or path @> \'' + paths[i] + '\'';
        }
        let sql = 'select array_to_json(array_agg(row_to_json(d))) \
                from (select id, tag, name, memo, pid, ui_show, path, nlevel(path) as depth, order_id from tb_acs_module  '
          + where_str + ')';
        sql += ' ORDER BY order_id, path)  as d;';
        try {
            let records = await AcsModule.sequelize!.query(sql, {type: QueryTypes.SELECT, raw: true});
            if (!records || records.length <= 0) {
                return resolve({
                    modules: []
                })
            }
            // @ts-ignore
            let rows_json: any = records[0].array_to_json;
            let tree_json: any[] = [];

            build_tree(rows_json, tree_json);

            let res_json = {
                tree: tree_json
            };
            return resolve(res_json);

        } catch (e) {
            reject(e);
        }

    })
}


export function build_tree(rows: any, tree: any) {
    for (let row of rows) {
        if (!insert_into_tree(row, tree)) {
            let node = {
                id: row.id,
                name: row.name,
                tag: row.tag,
                memo: row.memo,
                children: []
            }

            tree.push(node);
        }
    }

}

function insert_into_tree(row: any, tree: any): boolean {
    let result = false;
    for (let tree_node of tree) {

        let node = {
            id: row.id,
            name: row.name,
            tag: row.tag,
            memo: row.memo,
            children: []
        }

        if (row.pid == tree_node.id) {
            tree_node.children.push(node);
            result = true;
            break;
        }

        if (tree_node.children != undefined) {
            result = insert_into_tree(row, tree_node.children);
            if (result) break;
        }
    }

    return result;
}

export const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            }
        },
        "required": [
            "ver", "app_id", "timestamp"
        ]
    },
    method: get_tree,
    method_params:{}
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
