import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsModule} from "@core-models/AcsModule";
import DataCURD from "@core/DataCURD";

interface IData {
    id: string;
}

function get_where(json: IRequest, _params: IMethodParams, _cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let data: IData = <IData>json.data;
            resolve({id: data.id});
        } catch (e) {
            reject(e);
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "id": {
                        "type": "integer"
                    },
                    "name": {
                        "type": "string"
                    },
                    "ui_show": {
                        "type": "boolean"
                    },
                    "memo": {
                        "type": "string"
                    },
                    "order_id": {
                        "type": "integer"
                    }
                },
                "required": [
                    "id"
                ],
                "anyOf": [
                    {"required": ["name"]},
                    {"required": ["memo"]},
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp",
            "data"
        ]
    },
    method: DataCURD.internal_update_row,
    method_params: {
        model: AcsModule,
        where: get_where,
        input_data_map: {
            name: 'name',
            memo: 'memo',
        }
    }
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
