import {ADMINISTRATOR, IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsFunction} from "@core-models/AcsFunction";
import {AcsRoleFunction} from "@core-models/AcsRoleFunction";
import {AcsUserRole} from "@core-models/AcsUserRole";
import {QueryTypes} from "sequelize";
import {ISQLReplacements} from "@core/DataCURD";

interface IData {
    role_id: string;
    module_id: number;
}

function get_functions(json: IRequest, params: IMethodParams, cachedData: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        let sql = '';
        let user = cachedData.user_id;
        let data = <IData>json.data;
        let replacements: ISQLReplacements = {};
        if (user == ADMINISTRATOR) {
            sql = `select distinct ${AcsFunction.table_name}.id,${AcsFunction.table_name}.name,${AcsFunction.table_name}.api,
                                   (${AcsFunction.table_name}.id in ( 
                    select ${AcsRoleFunction.table_name}.func_id 
                    from ${AcsRoleFunction.table_name},${AcsFunction.table_name} 
                        where ${AcsRoleFunction.table_name}.role_id = :role_id
                        and ${AcsRoleFunction.table_name}.func_id = ${AcsFunction.table_name}.id 
                    )
                ) as enabled 
                    from ${AcsFunction.table_name} 
                    where ${AcsFunction.table_name}.module_id = :module_id
                    and ${AcsFunction.table_name}.check_auth = true`;
            replacements.role_id = data.role_id;
            replacements.module_id = data.module_id;
        } else {
            sql = `select distinct ${AcsFunction.table_name}.id,${AcsFunction.table_name}.name,${AcsFunction.table_name}.api,
                                   (${AcsFunction.table_name}.id in ( 
                    select ${AcsRoleFunction.table_name}.func_id 
                    from ${AcsRoleFunction.table_name},${AcsFunction.table_name} 
                    where ${AcsRoleFunction.table_name}.role_id = :role_id
                    and ${AcsRoleFunction.tableName}.func_id = ${AcsFunction.tableName}.id 
                )) as enabled 
                from ${AcsFunction.tableName},${AcsRoleFunction.tableName} 
                where role_id in (select role_id from ${AcsUserRole.tableName} where user_id = :user_id) 
                and ${AcsFunction.tableName}.id = ${AcsRoleFunction.tableName}.func_id 
                and ${AcsFunction.tableName}.module_id = :module_id
                and ${AcsFunction.tableName}.check_auth = true`;
            replacements.role_id = data.role_id;
            replacements.user_id = user;
            replacements.module_id = data.module_id;
        }

        try {
            let result = await AcsRoleFunction.sequelize!.query(sql, {type: QueryTypes.SELECT, replacements: replacements});
            let res_json = {
                funcs: result
            };
            resolve(res_json);
        } catch (e) {
            reject(e);
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "role_id": {
                        "type": "string"
                    },
                    "module_id": {
                        "type": "integer"
                    }
                },
                "required": [
                    "role_id",
                    "module_id"
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp", "data"
        ]
    },
    method: get_functions,
    method_params:{},
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
