import {ADMINISTRATOR, IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsRole} from "@core-models/AcsRole";
import {AcsUserRole} from "@core-models/AcsUserRole";
import {AcsRoleFunction} from "@core-models/AcsRoleFunction";
import {ISQLReplacements} from "@core/DataCURD";
import {Logger} from "@util/Logger";

interface IData {
    keyword: string;
}

function get_role_list(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        let data = <IData>json.data;
        let user = cached_data.user_id;
        let sql;
        let replacements: ISQLReplacements = {};
        if (user == ADMINISTRATOR) {
            sql = `select id, name from ${AcsRole.table_name} where tag = 'sys' `;
            if (data.keyword != undefined) {
                sql += ` and id like :keyword or name like :keyword`;
                replacements.keyword = `%${data.keyword}%`;
            }
            sql += ' order by id ';

        } else {
            sql = `select id, name from ${AcsRole.table_name} where id not IN ( 
                    SELECT DISTINCT role_id 
                    FROM ${AcsRoleFunction.table_name} a 
                    WHERE NOT exists 
                    ( 
                        SELECT func_id 
                        FROM ${AcsRoleFunction.table_name}, ${AcsUserRole.table_name}
                        WHERE 
                            ${AcsRoleFunction.table_name}.role_id = ${AcsUserRole.table_name}.role_id AND 
                            ${AcsUserRole.table_name}.user_id = '${user}' and func_id = a.func_id 
                    )
                    
                )`;
            if (data.keyword != undefined) {
                sql += ` and (id like :keyword or name like :keyword)`
                replacements.keyword = `%${data.keyword}%`;
            }

            sql += ' and tag = \'sys\' order by id '

        }

        // console.log(sql);

        try {
            let [rows, metadata]  = await AcsRole.sequelize!.query(sql, {raw: true, replacements: replacements});
            // let roles = result.rows[0].array_to_json !== null?result.rows[0].array_to_json:[]
            let res_json = {
                roles: rows
            }
            resolve(res_json);
        } catch (e) {
            reject(e);
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "title": "获取角色列表",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "keyword": {
                        "type": "string",
                        "title": "关键词，模糊匹配角色id，角色名称"
                    }
                }
            }
        },
        "required": [
            "ver", "app_id", "timestamp", "data"
        ]
    },
    method: get_role_list,
    method_params: {}
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
