
import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsRole} from "@core-models/AcsRole";
import DataCURD from "@core/DataCURD";
import {WhereOptions} from "sequelize";

interface IData {
    role_id: string;
}

function get_where(json: IRequest, _params: IMethodParams, _cached_data: ICachedData): Promise<WhereOptions> {
    return new Promise<WhereOptions>(async (resolve, reject) => {
        try {
            let data = <IData>json.data;
            resolve({id: data.role_id});
        } catch (e) {
            reject(e);
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "role_id": {
                        "type": "string"
                    },
                    "role_name": {
                        "type": "string"
                    },
                },
                "required": [
                    "role_id",
                    "role_name"
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp",
            "data",
        ]
    },
    method: DataCURD.internal_update_row,
    method_params: {
        model: AcsRole,
        where: get_where,
        input_data_map: {
            role_name: 'name'
        }
    },
    // guards: [roleGuard]
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
