import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsRole} from "@core-models/AcsRole";
import {AcsRoleFunction} from "@core-models/AcsRoleFunction";

interface IData {
    role_id: string;
}

function do_remove(json: IRequest, _params: IMethodParams, _cached_data: ICachedData){
    return new Promise<unknown>(async (resolve, reject) => {
        let t = await AcsRole.sequelize!.transaction();
        try {
            let data = <IData>json.data;
            await AcsRoleFunction.destroy({where: {role_id: data.role_id}, transaction: t});
            await AcsRole.destroy({where: {id: data.role_id}, transaction: t});
            await t.commit();
            resolve({});
        } catch (e) {
            await t.rollback();
            reject(e);
        }
    })
}


const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "role_id": {
                        "type": "string"
                    }
                },
                "required": [
                    "role_id"
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp",
            "data"
        ]
    },
    method: do_remove,
    method_params: {
        model: AcsRole,
    },
    // guards: [roleGuard]
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
