import {ADMINISTRATOR, IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsRole} from "@core-models/AcsRole";
import {AcsRoleFunction} from "@core-models/AcsRoleFunction";
import {AcsUserRole} from "@core-models/AcsUserRole";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {QueryTypes} from "sequelize";
import {subAccountGuard} from "@src/guards/subAccountGuard";

interface IData{
    user_id: string;
}

function get_roles(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<unknown>(async (resolve, reject) => {
        // let params: IParams = <IParams>json;
        let data = <IData>json.data;
        try {
            if (data.user_id !== undefined) {
                data.user_id = data.user_id.toLowerCase();
            }

            let sql;
            let values = [];
            let user = cached_data.user_id;
            if (data.user_id === undefined) {//user_id为空时表示取自身的角色列表
                if (user == ADMINISTRATOR) {
                    sql = ` select id, name from ${AcsRole.table_name} `;
                } else {
                    sql = ` select id, name from ${AcsRole.table_name}where id not IN ( 
                    SELECT DISTINCT role_id 
                    FROM ${AcsRoleFunction.table_name} a 
                    WHERE NOT exists 
                    ( 
                        SELECT func_id 
                        FROM ${AcsRoleFunction.table_name},${AcsUserRole.table_name}
                        WHERE 
                        ${AcsRoleFunction.table_name}.role_id = ${AcsUserRole.table_name}.role_id AND 
                        ${AcsUserRole.table_name}.user_id = '${user}' and func_id = a.func_id 
                    )
                )`
                 // and domain_id IN (
                 //    SELECT id  FROM ${Domain.tableName}
                 //    WHERE path <@
                 //        ( SELECT path FROM ${Domain.tableName} WHERE id IN ( SELECT domain_id FROM ${UserDomain.tableName} WHERE user_id = '${user}' ) )
                 //    ORDER BY  path )`;
                }

            } else {//取自己权限下可分配的角色列表以及某用户已分配的角色
                if (user == ADMINISTRATOR) {
                    sql = ` select id, name, 
                    exists( 
                        select role_id from ${AcsUserRole.tableName} 
                        where user_id = '${data.user_id}' and role_id = b.id 
                        ) as enabled 
                    from tb_acs_role b`;
                } else {
                    sql = ` select id, name, 
                    exists( 
                        select role_id from ${AcsUserRole.tableName}  
                        where user_id = '${data.user_id}' and role_id = b.id 
                        ) as enabled
                            from ${AcsRole.tableName} b where id not IN ( 
                    SELECT DISTINCT role_id 
                    FROM ${AcsRoleFunction.tableName} a 
                    WHERE NOT exists 
                    ( 
                        SELECT func_id 
                        FROM ${AcsRoleFunction.tableName},${AcsUserRole.tableName}
                        WHERE 
                        ${AcsRoleFunction.tableName}.role_id = ${AcsUserRole.tableName}.role_id AND 
                        ${AcsUserRole.tableName}.user_id = '${user}' and func_id = a.func_id 
                    )
                )`
                    // and domain_id IN (
                    //  SELECT id  FROM ${Domain.tableName}
                    //  WHERE path <@ ( SELECT path FROM ${Domain.tableName}
                    //     WHERE id IN ( SELECT domain_id FROM ${UserDomain.tableName} WHERE user_id = '${user}' ) )
                    // ORDER BY  path )`;

                }

            }

            try{
                // let db = Database.getInstance('biz');
                // Logger.debug(sql);
                let result  = await AcsUserInfo.sequelize!.query(sql, {type: QueryTypes.SELECT});
                resolve({
                    roles: result
                });

            }catch (e) {
                reject(e);
            }


        } catch (e) {
            reject(e);
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "user_id": {
                        "type": "string",
                        "maxLength": 15,
                        "minLength": 2
                    }
                },
                "required": [
                    "user_id"
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp", "data"
        ]
    },
    method: get_roles,
    method_params: {},
    guards: [subAccountGuard]
}

module.exports = {
    default: v1_0,
    v1_0: v1_0,
}
