import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {AcsUserRole} from "@core-models/AcsUserRole";
import {AcsUserDomain} from "@core-models/AcsUserDomain";
import {subAccountGuard} from "@src/guards/subAccountGuard";

interface IData {
    user_id: string;
}

function remove(json: IRequest, _params: IMethodParams, _cached_data: ICachedData): Promise<any> {
    return new Promise<unknown>(async (resolve, reject) => {
        let data = <IData>json.data;
        data.user_id = data.user_id.toLowerCase();
        let t = await AcsUserInfo.sequelize!.transaction();
        try {
            await AcsUserRole.destroy({where: {user_id: data.user_id}, transaction: t});
            await AcsUserDomain.destroy({where: {user_id: data.user_id}, transaction: t});
            await AcsUserInfo.destroy({where: {id: data.user_id}, transaction: t});

            await t.commit();
            resolve({});
        } catch (e) {
            await t.rollback();
            reject(e);
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "user_id": {
                        "type": "string",
                        "maxLength": 15,
                        "minLength": 2
                    }
                },
                "required": [
                    "user_id"
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp",
            "data"
        ]
    },
    method: remove,
    method_params: {
    },
    guards: [subAccountGuard]

}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
