import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {roleGuard} from "@src/guards/roleGuard";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {AcsUserRole} from "@core-models/AcsUserRole";

interface IRole {
    id: string;
    enabled: boolean;
}

interface IData {
    user_id: string;
    roles: Array<IRole>;
}

function set_roles(json: IRequest, _params: IMethodParams, _cached_data: ICachedData): Promise<any> {
    return new Promise<unknown>(async (resolve, reject) => {
        let data = <IData>json.data;
        data.user_id = data.user_id.toLowerCase();
        try {
            let insert_values = '';
            let delete_values = '';
            let sql_list: Array<string> = [];

            for (let i = 0; i < data.roles.length; i++) {
                let item = data.roles[i];
                if (item.enabled == true) {
                    if (insert_values != '') {
                        insert_values += ',';
                    }
                    insert_values += '(\'' + data.user_id + '\', \'' + item.id + '\')';
                } else {
                    if (delete_values != '') {
                        delete_values += ' or ';
                    }
                    delete_values += 'role_id = \'' + item.id + '\'';
                }
            }
            if (insert_values != '') {
                let sql = `insert into  ${AcsUserRole.table_name} (user_id, role_id) with tmp(f1, f2) as ( values ${insert_values})
                           select a.*from tmp as a where a.f2 not in (select role_id from ${AcsUserRole.table_name} as b
                    where user_id = a.f1)`;
                sql_list.push(sql);

            }

            if (delete_values != '') {
                let sql = `delete from ${AcsUserRole.table_name} where user_id='${data.user_id}' and (${delete_values})`;
                sql_list.push(sql);
            }
            let t = await AcsUserInfo.sequelize!.transaction();
            try {
                for (let i = 0; i < sql_list.length; i++) {
                    await AcsUserInfo.sequelize!.query(sql_list[i], {transaction: t});
                }

                await t.commit();
                resolve({});

            } catch (e) {
                await t.rollback();
                reject(e);
            }


        } catch (e) {
            reject(e);
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "user_id": {
                        "type": "string",
                        "maxLength": 15,
                        "minLength": 2
                    },
                    "roles": {
                        "type": "array",
                        "items": {
                            "type": "object",
                            "properties": {
                                "id": {
                                    "type": "string"
                                },
                                "enabled": {
                                    "type": "boolean"
                                }
                            },
                            "required": [
                                "id",
                                "enabled"
                            ]
                        }
                    }
                },
                "required": [
                    "user_id",
                    "roles"
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp",
            "data",
        ]
    },
    method: set_roles,
    method_params: {},
    guards: [roleGuard]
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
