import {ADMINISTRATOR, IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsRoleFunction} from "@core-models/AcsRoleFunction";
import {AcsUserRole} from "@core-models/AcsUserRole";
import {AcsFunction} from "@core-models/AcsFunction";
import {QueryTypes} from "sequelize";

interface IResponse {
    list: Array<any>;
}

function get_permissions(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<IResponse> {
    return new Promise<IResponse>(async (resolve, reject) => {
        let user = cached_data.user_id;
        try {
            let sql;
            if (user == ADMINISTRATOR) {
                sql = ` SELECT  api
                    FROM  ${AcsFunction.table_name} 
                `;
            } else {
                sql = ` SELECT distinct func.api as api
                    FROM ${AcsRoleFunction.table_name} role_func,${AcsUserRole.table_name} user_role,${AcsFunction.table_name} func
                    WHERE 
                    role_func.role_id = user_role.role_id AND 
                    user_role.user_id = :user_id and role_func.func_id = func.id
                    order by api
                `;
            }
            let result: any = await AcsFunction.sequelize!.query(sql, {type: QueryTypes.SELECT, raw: true, replacements: {user_id: user}});
            let list: Array<string> = [];
            if (result && result.length > 0) {
                for (let i = 0; i < result.length; i++) {
                    list.push(result[i].api)
                }
            }
            return resolve({list: list});
        } catch (e) {
            return reject(e);
        }
    })
}


const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
        },
        "required": [
            "ver", "app_id", "timestamp",
        ]
    },
    method: get_permissions,
    method_params:{
    }
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
