/**
 * 获取自身账户详情
 */
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {Resp} from "@util/Resp";
import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import DataCURD from "@core/DataCURD";

function get_where(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let where: any = {id: cached_data.user_id};
            return resolve(where);
        } catch (e) {
            reject(Resp.gen_err(Resp.InternalServerError));
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "title": "获取自身账户详情",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
        },
        "required": [
            "ver", "app_id", "timestamp",
        ]
    },
    method: DataCURD.internal_get_row,
    method_params: {
        model: AcsUserInfo,
        where: get_where,
        output_data_map: {
            id: 'user_id',
            'name': 'name',
            'mobile': 'mobile',
            'email': 'email',
            'reg_time': 'reg_time',
            'act_time': 'act_time'
        },
    },
    guards: []
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
