import {IApiProcessor, IMethodParams} from "@core/Defined";
const vcode = require('svg-captcha');
import {v4 as uuid} from 'uuid';
import {Redis} from "@util/Redis";

function get_vcode(json: any, params: IMethodParams, cachedData: any): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {

            let options = {
                size: 4, // 随机生成验证码长度
                ignoreChars: "0o1iIl",
                noise: 4,  // 设置干扰线的数量
                // color: false, //验证码字符是否有颜色，默认是没有，但是如果设置了背景颜色，那么默认就是有字符颜色
                // inverse: true,
                // background: "#FFF", // 背景颜色
                fontSize: 50, // 设置字体大小
                width: 150, //宽度
                height: 50, //高度
            };
            const code = vcode.create(options);
            console.log(options);
            const data = new Buffer(code.data).toString('base64');
            let base64 = 'data:image/svg+xml;base64,' + data;

            let vcode_session: string = uuid();
            let redis = Redis.get_instance('client-token');
            await redis.set(vcode_session, code.text.toLowerCase(), 300);
            console.log(`vcode_session: ${vcode_session}, vcode: ${code.text}`);

            return resolve({session: vcode_session, pic: base64});
        } catch (e) {
            return reject(e);
        }
    })
}


const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "title": "获取图形验证码",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "test": {
                "type": "string",
                "pattern": "^(20|21|22|23|[0-1]\\d):[0-5]\\d$"
            }
        },
        "required": [
            "ver", "app_id", "timestamp",
        ]
    },
    method: get_vcode,
    method_params:{
    }
};

module.exports = {
    default: v1_0,
    v1_0: v1_0
};
