import {IApiProcessor, IMethodParams, IRequest} from "@core/Defined";
import {Redis} from "@util/Redis";

function logout(content: IRequest, param: IMethodParams, cachedData: any): Promise<void> {
    return new Promise<void>(async (resolve, reject) => {
        if (!content.token) return resolve();
        let redis = Redis.get_instance('client-token');
        await redis.del(content.token);
        resolve();
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
        },
        "required": [
            "ver", "app_id", "timestamp", "token"
        ]
    },
    method: logout,
    method_params:{
    }
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
