/**
 * 设置自身账户详情
 */
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {Resp} from "@util/Resp";
import {IApiProcessor, IMethodParams} from "@core/Defined";
import DataCURD from "@core/DataCURD";
import {Logger} from "@util/Logger";
import {Op} from "sequelize";

function getWhere(json: any, params: IMethodParams, cachedData: any): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let where: any = {id: cachedData.userId};
            return resolve(where);
        } catch (e) {
            reject(Resp.gen_err(Resp.InternalServerError));
        }
    });
}
function setSelfInfo(json: any, params: IMethodParams, cachedData: any): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        let t = await AcsUserInfo.sequelize!.transaction();
        try{
            if(json.new_pass) {
                let userInfo = await AcsUserInfo.findOne({where: {id: cachedData.userId}, raw: true, transaction: t});
                if (!userInfo) return reject(Resp.gen_err(Resp.ResourceNotFound, '账号不存在'));
            }
            if (json.mobile !== undefined) {
                let userInfo = await AcsUserInfo.findOne({where: {mobile: json.mobile, id: {[Op.ne]:  json.user_id}}, raw: true, transaction: t});
                if (userInfo) {
                    await t.rollback();
                    return reject(Resp.gen_err(Resp.DataExists, `手机号为${json.mobile}的账号已存在，不允许修改。`))
                }

            }
            let result = await DataCURD.internal_update_row(json, params, cachedData, t);
            await t.commit();
            resolve(result);

        }catch (e) {
            Logger.error(e);
            await t.rollback();
            return reject(Resp.gen_db_err(e));
        }

    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "title": "设置自身账户详情",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },

            "name": {
                "type": "string",
                "title": "实体卡用户名称"
            },
            "mobile": {
                "type": "string",
                "pattern": "^$|^(13[0-9]|14[01456879]|15[0-3,5-9]|16[2567]|17[0-8]|18[0-9]|19[0-3,5-9])\\d{8}$",

            },
            "email": {
                "type": "string",
                "pattern": "^$|^[a-zA-Z0-9_-]+@[a-zA-Z0-9_-]+(\\.[a-zA-Z0-9_-]+)+$",

            },
            "old_pass": {
                "type": "string",
                "title": "MD5 32位小写后的旧密码"
            },
            "new_pass": {
                "type": "string",
                "title": "MD5 32位小写后的新密码"
            }
        },
        "required": [
            "ver", "app_id", "timestamp",
        ],
        "anyOf": [
            {"required": ["name"]},
            {"required": ["mobile"]},
            {"required": ["email"]},
            {"required": ["new_pass"]},
        ]
    },
    method: setSelfInfo,
    method_params: {
        model: AcsUserInfo,
        input_data_map: {
            name: 'name',
            mobile: 'mobile',
            email: 'email',
            new_pass: 'pass'
        },
        output_data_map: {

        },
        where: getWhere
    },
    guards: []
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
