import {ServiceApp} from "@core/App";
import {MyRouter} from "@src/MyRouter";
import {guards} from "@src/guards/guards";
import {Models} from "@src/models/Models";
import dayjs from "dayjs";

import utc from "dayjs/plugin/utc";
import timezone from "dayjs/plugin/timezone";
import {Oss} from "@util/Oss";
import {Logger} from "@util/Logger";
import {PrjTaskOutcome} from "@core-models/PrjTaskOutcome";
import {BizContractInfo} from "@core-models/BizContractInfo";
import {PrjFile} from "@core-models/PrjFile";
import {FlowEngine} from "@src/bpmn/flow_engine";
import {BpmnCase} from "@core-models/BpmnCase";
import {bpmn_flow_on_end} from "@src/utils/bpmn_work_helper";
import {OutcomeStatus} from "@src/utils/define";
import {prj_stat_monthly, task_delay_rate_daily, task_stat_daily} from "@src/utils/prj_stat";
const { report } = require('node:process');

const schedule = require('node-schedule');

dayjs.extend(utc);
dayjs.extend(timezone);
dayjs.tz.guess();
// dayjs.tz("2014-06-01 12:00", "Asia/Shanghai")
new ServiceApp().start(new MyRouter('@src/routes', guards), Models).then(async () => {
    // await bpmn_flow_on_end('63dcaf1fe8000000', 'plan_alter', '63daded44f000000', 'admin');
    try {
        let oss = Oss.get_instance('pmr-doc');
        if (!await oss.bucket_exists(oss.bucket)) {
            await oss.make_bucket(oss.bucket);
        }
        // 侦听oss上传消息，更新喊话日志表中语音是否已上传字段
        oss.listenBucketNotification(oss.bucket, '', '*', ['s3:ObjectCreated:*'],
            async function (record: any) {
                Logger.info(record);
                let path = record.object.split('/');
                let t = await PrjFile.sequelize!.transaction();
                try {
                    switch (path[0]) {
                        case 'project':
                            switch (path[2]) {
                                case 'outcome':
                                    let outcome_id = path[3];
                                    if (outcome_id) {
                                        let [count, result] = await PrjTaskOutcome.update({status: OutcomeStatus.Uploaded, uploaded: true}, {
                                            where: {id: outcome_id},
                                            returning: ['id', 'task_id'],
                                            transaction: t
                                        });
                                    }
                                    break;
                                case 'week_report':
                                    break;
                            }
                            await PrjFile.update({
                                uploaded_at: dayjs().format('YYYY-MM-DD HH:mm:ss'),
                                uploaded: true,
                                size: record.size
                            }, {where: {id: record.object.key}, transaction: t})
                            break;
                        case 'contract':
                            let contract_id = path[1];
                            if (!contract_id) break;
                            switch (path[2]) { // 附件类型
                                case '10': //打印件
                                    await BizContractInfo.update({
                                        doc_uploaded: true,
                                        doc_uploaded_at: dayjs(),
                                        doc_size: record.size
                                    }, {
                                        where: {id: contract_id},
                                        transaction: t
                                    })
                                    break;
                                case '20':  // 扫描件
                                    await BizContractInfo.update({
                                        pdf_uploaded: true,
                                        pdf_uploaded_at: dayjs(),
                                        pdf_size: record.size
                                    }, {
                                        where: {id: contract_id},
                                        transaction: t
                                    })
                                    break;
                            }
                            break;
                        default:

                            break;
                    }
                    await PrjFile.update({
                        uploaded_at: dayjs(),
                        uploaded: true,
                        size: record.size
                    }, {where: {id: record.object}})
                    await t.commit();
                } catch (e) {
                    await t.rollback();
                    Logger.error(e);
                }

            });
    } catch (e) {
        console.log(e);
    }

    // TODO: 清理PrjFile中未上传或上传后必须有依赖但没有依赖的文件
    //
    // let flow_source = await BpmnModel.findOne({where: {id: 'prj'}});
    // if (!flow_source) return;
    // let flow = new FlowEngine(flow_source.content, {prj_id: '63b0e938d7800000', owner: '18688270331'});


    let flow_cases = await BpmnCase.findAll({where: {completed_at: null}, raw: true});
    for (let flow of flow_cases) {
        await new FlowEngine(flow.model_id, flow.model, {
            prj_id: flow.prj_id,
            owner: flow.creator_id,
            id: flow.id
        }, bpmn_flow_on_end).run(flow.state);
    }

    // 项目数统计
    schedule.scheduleJob('50 23 * * *', async function () {
        await prj_stat_monthly();
        await task_stat_daily();
        await task_delay_rate_daily();
    });

    // let bpmn = await BpmnModel.findOne({where: {id: 'task'}, raw: true});
    // if (bpmn) {
    //
    //     let flow =  new FlowEngine('task', bpmn.content, {
    //             prj_id: '63daded44f000000',
    //             owner: 'admin',
    //             task_id: '63e1c7d7c6800000'
    //         },
    //         bpmn_flow_on_end
    //     );
    //     await BpmnCase.create({
    //         id: flow.id,
    //         model_id: bpmn.id,
    //         model: bpmn.content,
    //         started_at: dayjs(),
    //         creator_id: 'admin',
    //         prj_id: '63daded44f000000',
    //         // state: await flow.state(),
    //     }, {});
    //     await flow.run();
    // }
/*
    console.log(`Reports are compact? ${report.compact}`);
    const data = report.getReport();
    console.log(data.header.cpus);

    // 自动到MQTT服务上注册尚未注册的设备
    const job = schedule.scheduleJob('* * * * * *', async function () {
        // console.log(new Date());
        const data = report.getReport();
        try {
            let cpus: string = '';
            let totalUsage = 0;
            let totalIdle = 0;
            for (let i = 0; i < data.header.cpus.length; i++) {
                let cpu = data.header.cpus[i];
                totalUsage += (cpu.user + cpu.nice + cpu.sys + cpu.irq);
                totalIdle += cpu.idle;
            }
            const totalTick = totalIdle + totalUsage;
            const cpuUsage = totalUsage / totalTick * 100;

            const totalMemory = data.resourceUsage.total_memory;
            const usedMemory = data.resourceUsage.maxRss;
            const memoryUsagePercent = (usedMemory / totalMemory) * 100;
            console.log(`
            time: ${data.header.dumpEventTime}
            CPUs: ${cpuUsage.toFixed(2)} %
            Mem: ${memoryUsagePercent.toFixed(2)} %  used ${formatBytes(usedMemory)}
            
            `);

        } catch (e) {
            Logger.error(e);
        }
    });
*/
});


// function formatBytes(bytes, decimals = 2) {
//     if (bytes === 0) return '0 Bytes';
//     const k = 1024;
//     const dm = decimals < 0 ? 0 : decimals;
//     const sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
//     const i = Math.floor(Math.log(bytes) / Math.log(k));
//     return parseFloat((bytes / Math.pow(k, i)).toFixed(dm)) + ' ' + sizes[i];
// }