import {Resp} from "@util/Resp";
import {ADMINISTRATOR, ICachedData, IRequest} from "@core/Defined";
import {AcsDomain} from "@core-models/AcsDomain";
import {QueryTypes} from "sequelize";

export function domainGuard(json: IRequest, cached_data: ICachedData): Promise<void> {
    return new Promise<void>(async (resolve, reject) => {
        let user = cached_data.user_id;
        let data: any = json.data;
        if (!user) return reject(Resp.gen_err(Resp.Forbidden));
        if (user === ADMINISTRATOR) return resolve();
        let id = data.area_id || data.domain_id || data.pid || data.group_id || data.id ;
        if (id === undefined)
            return reject(Resp.gen_err(Resp.ParamsError, '<guard> should have required property \'domain_id\''));
        try {
            let result = await AcsDomain.sequelize!.query(`
                select tb_acs_domain.id 
                from tb_acs_user_domain, tb_acs_domain 
                where tb_acs_user_domain.domain_id = tb_acs_domain.id 
                    and tb_acs_user_domain.user_id = :user
                and path @> (select path from tb_acs_domain where tb_acs_domain.id=:id)
                order by path;`, {type: QueryTypes.SELECT, raw: true, replacements: {user: user, id: id}});
            if (result.length < 1) {
                return reject(Resp.gen_err(Resp.Forbidden, `${user}:${id} domain`));
            }
            resolve();
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    });
}


export function domainsGuard(json: IRequest, cached_data: ICachedData): Promise<void> {
    return new Promise<void>(async (resolve, reject) => {
        let user = cached_data.user_id;
        let data: any = json.data;
        if (!user) return reject(Resp.gen_err(Resp.Forbidden));
        if (user === ADMINISTRATOR) return resolve();
        let domains = data.domains || data.groups;
        if (domains === undefined) return reject(Resp.gen_err(Resp.ParamsError, 'should have required property \'domains\' or \'groups\''));
        if (domains.length === 0) return resolve();
        let ids: Array<number> = [];
        if (domains[0] instanceof Object) {
            for (let i = 0; i < domains.length; i++) {
                ids.push(domains[i].id);
            }
        } else {
            ids = [...domains]
        }

        // let domains: any = json.domains;

        try {
            for (let i = 0; i < ids.length; i++) {
                let domain_id = ids[i];
                let result = await AcsDomain.sequelize!.query(`
                    select tb_acs_domain.id 
                    from tb_acs_user_domain, tb_acs_domain 
                    where tb_acs_user_domain.domain_id = tb_acs_domain.id 
                        and tb_acs_user_domain.user_id = :user
                    and path @> (select path from tb_acs_domain where tb_acs_domain.id = :domain_id)
                    order by path;`, {type: QueryTypes.SELECT, raw: true, replacements: {user: user, domain_id: domain_id}});
                if (result.length < 1) {
                    return reject(Resp.gen_err(Resp.Forbidden, `${user}:${domain_id} domain`));
                }
            }

            resolve();
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    });
}
