import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {QueryTypes, WhereOptions} from "sequelize";
import {PrjInfo} from "@core-models/PrjInfo";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import DataCURD from "@core/DataCURD";
import {BizContractInfo} from "@core-models/BizContractInfo";
import dayjs from "dayjs";
import {PrjFile} from "@core-models/PrjFile";
import {BizCustomer} from "@core-models/BizCustomer";
import {AcsDomain} from "@core-models/AcsDomain";
import {BizCustomerIndustry} from "@core-models/BizCustomerIndustry";
import {BizCustomerLevel} from "@core-models/BizCustomerLevel";

interface IData {
    /**
     * 客户id
     */
    id: string;
}

function detail(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let data = <IData>json.data;
            let customer = await BizCustomer.sequelize!.query(`
                select customer.id, customer.name, 
                    customer.region_id, region.name as region_name,
                    customer.industry_id, industry.name as industry_name,
                    customer.level_id, level.name as level_name,
                    customer.link_man, customer.link_phone, customer.address, 
                    customer.invoice_title, customer.tax_no,
                    customer.bank_name, customer.bank_account, 
                    customer.invoice_addr, customer.invoice_phone, customer.memo,
                    customer.bizman_id, bizman.name as bizman_name,
                    TO_CHAR(customer.created_at, 'yyyy-MM-dd HH24' || ':' || 'MI' || ':' || 'ss') as created_at
                    
                from ${BizCustomer.table_name} customer
                left join ${AcsDomain.table_name} region on region.id = customer.region_id
                left join ${BizCustomerIndustry.table_name} industry on industry.id = customer.industry_id
                left join ${BizCustomerLevel.table_name} level on level.id = customer.level_id
                left join ${AcsUserInfo.table_name} bizman on bizman.id = customer.bizman_id
                where customer.id = :customer_id 
            `, {type: QueryTypes.SELECT, raw: true, replacements: {
                    customer_id: data.id
                }})
            if(!customer || customer.length <= 0) return reject(Resp.gen_err(Resp.ResourceNotFound));
            let result = DataCURD.filter_null(customer[0]);

            resolve(result);
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "id": {
                        "type": "string",
                        "title": "客户id"
                    }
                },
                "x-apifox-orders": [
                    "id"
                ],
                "title": "请求参数内容",
                "required": [
                    "id"
                ]
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: detail,
    method_params: {},
    guards: []
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
