import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import DataCURD from "@core/DataCURD";
import {WhereOptions} from "sequelize";
import {BizCustomer} from "@core-models/BizCustomer";

interface IData {
    id: string;
}

async function get_where(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<WhereOptions> {
    let data = <IData>json.data;
    return {id: data.id};
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "title": "删除客户记录",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "id": {
                        "type": "string",
                        "title": "客户编号"
                    }
                },
                "required": [
                    "id"
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp", "data"
        ]
    },
    method: DataCURD.internal_remove_row,
    method_params: {
        model: BizCustomer,
        where: get_where
    }
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
