import {IApiProcessor} from "@core/Defined";
import {AcsDomain} from "@core-models/AcsDomain";
import DataCURD from "@core/DataCURD";

// interface IData {
//     pid: number;
//     name: string;
//     memo?: string;
// }
//
// function add(json: IRequest, _param: IMethodParams, _cached_data: ICachedData): Promise<unknown> {
//     return new Promise<unknown>(async (resolve, reject) => {
//         let data: IData = <IData>json.data;
//         try {
//             let parent_path = await get_parent_path(data);
//             let result = await do_add(data, parent_path);
//             resolve(result);
//         } catch (e) {
//             reject(e);
//         }
//     });
// }
//
// function get_parent_path(params: IData): Promise<string> {
//     return new Promise<string>(async (resolve, reject) => {
//         try {
//             let record = await AcsDomain.findOne({where: {id: params.pid},raw: true});
//             if (!record)  return reject(Resp.gen_err(Resp.Forbidden));
//             resolve(record.path);
//         } catch (e) {
//             reject(e);
//         }
//     });
// }
//
// function do_add(params: IData, parent_path: string): Promise<unknown> {
//     return new Promise<unknown>(async (resolve, reject) => {
//         let sql: string;
//         let replacements: ISQLReplacements = {};
//         if (params.pid === 0) {
//             sql = `insert into ${AcsDomain.table_name} (name, pid, path, memo, tag)
//                 values(:name, ${params.pid}, text2ltree(to_char(nextval('tb_acs_domain_id_seq')-1, 'FM999999999')),
//                 :memo, :tag) returning id`;
//             replacements = {name: params.name, memo: params.memo, category: 'org'};
//         } else {
//             sql = `insert into ${AcsDomain.table_name} (name, pid, path, memo, tag)
//              values(:name, ${params.pid},
//              text2ltree( :parent_path || '.' || to_char(nextval('tb_acs_domain_id_seq')-1, 'FM999999999')),
//              :memo, :tag) returning id`;
//             replacements = {name: params.name, parent_path: parent_path, memo: params.memo, category: 'org'};
//         }
//         try {
//             const [results, metadata] = await AcsDomain.sequelize!.query(sql, {replacements: replacements});
//             if (!results) return reject(Resp.gen_err(Resp.PostgresqlServerError));
//             resolve({
//                 id: (<AcsDomain>results[0]).id
//             });
//         } catch (e) {
//             reject(Resp.gen_db_err(e));
//         }
//     })
// }

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "name": {
                        "type": "string",
                        "title": "部门名称"
                    },
                    "memo": {
                        "type": "string"
                    }
                },
                "x-apifox-orders": [
                    "name",
                    "memo"
                ],
                "required": [
                    "name"
                ],
                "title": "请求参数内容"
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "examples": [
                    "1.0"
                ],
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。",
                "default": "f2741721-1c07-430e-9f01-5529692340f9"
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理",
                "default": null
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: DataCURD.internal_add_tree_node,
    method_params: {
        model: AcsDomain,
        addition: {
            pid: 1000,
            category: 'org'
        }
    }
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
