import {ADMINISTRATOR, IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsDomain} from "@core-models/AcsDomain";
import DataCURD from "@core/DataCURD";

interface IData {
    id: string;
    name?: string;
    memo?: string;
}

function get_where(json: IRequest, _params: IMethodParams, _cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let data: IData = <IData>json.data;
            resolve({id: data.id, category: 'org'});
        } catch (e) {
            reject(e);
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "name": {
                        "type": "string",
                        "title": "部门名称"
                    },
                    "memo": {
                        "type": "string",
                        "title": "备注"
                    },
                    "id": {
                        "type": "integer",
                        "title": "部门id"
                    }
                },
                "x-apifox-orders": [
                    "id",
                    "name",
                    "memo"
                ],
                "required": [
                    "id"
                ],
                "anyOf": [
                    {
                        "required": [
                            "name"
                        ]
                    },
                    {
                        "required": [
                            "memo"
                        ]
                    }
                ],
                "title": "请求参数内容"
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "examples": [
                    "1.0"
                ],
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: DataCURD.internal_update_row,
    method_params:{
        model: AcsDomain,
        where: get_where,
        input_data_map: {
            name: 'name',
            memo: 'memo'
        }
    }
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
