import {AcsDomain} from "@core-models/AcsDomain";
import DataCURD from "@core/DataCURD";
import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";

interface IData {
    id: string;
}

function get_where(json: IRequest, _params: IMethodParams, _cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let data: IData = <IData>json.data;
            resolve({id: data.id, category: 'org'});
        } catch (e) {
            reject(e);
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "$schema": "http://json-schema.org/draft-07/schema#",
        "type": "object",
        "properties": {
            "ver": {
                "type": "string",
                "title": "版本号，默认1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "平台分配的app id"
            },
            "token": {
                "type": "string",
                "title": "登录后获得的令牌"
            },
            "timestamp": {
                "type": "integer",
                "title": "时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "data": {
                "type": "object",
                "title": "业务参数",
                "properties": {
                    "id": {
                        "type": "number"
                    }
                },
                "required": [
                    "id"
                ]
            }
        },
        "required": [
            "ver", "app_id", "timestamp",
            "data"
        ]
    },
    method: DataCURD.internal_remove_row,
    method_params: {
        model: AcsDomain,
        where: get_where
    }
}

module.exports = {
    default: v1_0,
    v1_0: v1_0,
}
