import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {Op, WhereOptions} from "sequelize";
import DataCURD from "@core/DataCURD";
import {AcsApplication} from "@core-models/AcsApplication";
import {BizCustomerIndustry} from "@core-models/BizCustomerIndustry";
import {PrjPhaseDefine} from "@core-models/PrjPhaseDefine";

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {},
                "x-apifox-orders": [],
                "title": "请求参数内容"
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "examples": [
                    "1.0"
                ]
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理",
                "title": "UTC时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "sign",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: DataCURD.internal_get_rows,
    method_params: {
        model: PrjPhaseDefine,
        // where: get_where,
        output_data_map: {
            id: 'id',
            name: 'name',
            color: 'color',
            order_index: 'order_index'
        },
        order: [['order_index', 'asc']]
    }
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
