import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {QueryTypes, WhereOptions} from "sequelize";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import DataCURD from "@core/DataCURD";
import {AcsDomain} from "@core-models/AcsDomain";
import {AcsUserDomain} from "@core-models/AcsUserDomain";
import {AcsUserRole} from "@core-models/AcsUserRole";
import {AcsRole} from "@core-models/AcsRole";
interface IData {
    /**
     * 员工 id
     */
    id: string;
}

function detail(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let data = <IData>json.data;
            let staffs = await AcsUserInfo.sequelize!.query(`
                select staff.id , staff.name,
                    staff.mobile, staff.email, staff.memo, user_role.role_id as role_id,
                    role.name as role_name,
                    COALESCE(staff.ext_info->'full_range', 'false')::boolean as full_range,
                    COALESCE(staff.ext_info->'level', '0')::integer as level,
                    staff.status,
                    domain.id as domain_id, domain.name as domain_name,
                    TO_CHAR(staff.reg_time, 'yyyy-MM-dd HH24' || ':' || 'MI' || ':' || 'ss') as reg_time,
                    TO_CHAR(staff.act_time, 'yyyy-MM-dd HH24' || ':' || 'MI' || ':' || 'ss') as act_time
                from ${AcsUserInfo.table_name} staff, ${AcsDomain.table_name} domain, ${AcsUserDomain.table_name} user_domain,
                    ${AcsUserRole.table_name} user_role, ${AcsRole.table_name} role
                where staff.id = :staff_id and staff.id = user_domain.user_id and domain.id = user_domain.domain_id,
                    user_role.user_id = staff.id and role.id = user_role.role_id
            `, {type: QueryTypes.SELECT, raw: true, replacements: {
                    staff_id: data.id
                }})
            if(!staffs || staffs.length <= 0) return reject(Resp.gen_err(Resp.ResourceNotFound));
            resolve(DataCURD.filter_null(staffs[0]));
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "id": {
                        "type": "string",
                        "title": "员工id"
                    }
                },
                "x-apifox-orders": [
                    "id"
                ],
                "title": "请求参数内容",
                "required": [
                    "id"
                ]
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: detail,
    method_params: {},
    guards: []
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
