import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {Op, Sequelize} from "sequelize";
import {Resp} from "@util/Resp";
import DataCURD from "@core/DataCURD";
import {AcsUserDomain} from "@core-models/AcsUserDomain";
import {AcsUserRole} from "@core-models/AcsUserRole";
interface IData {
    /**
     * 部门id
     */
    domain_id?: number;
    /**
     * 邮箱号
     */
    email?: string;
    /**
     * 是否可访问所有项目，默认为false，false时，只能访问身为项目组成员的项目，否则可以访问公司内部的所有项目
     */
    full_range?: boolean;
    /**
     * 员工 id
     */
    id: string;
    /**
     * 级别
     */
    level?: number;
    /**
     * 备注
     */
    memo?: string;
    /**
     * 客户名称
     */
    name?: string;
    /**
     * 密码，md5 32
     */
    pass?: string;
    /**
     * 角色id
     */
    role_id?: string;
    /**
     * 状态，0=锁定，1=正常
     */
    status?: number;
}


function get_where(json: IRequest, _params: IMethodParams, _cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let data = <IData>json.data;
            resolve({id: data.id});
        } catch (e) {
            reject(e);
        }
    })
}

function modify(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        let t = await AcsUserInfo.sequelize!.transaction();
        try {
            let data = <IData>json.data;
            let staff = await AcsUserInfo.findOne({where:{id: data.id}, transaction: t});
            if (!staff) throw Resp.gen_err(Resp.ResourceNotFound);
            data.name? staff.name = data.name : null;
            data.memo? staff.memo = data.memo: null;
            data.email? staff.email = data.email: null;
            data.pass? staff.pass =data.pass: null;


            let ext_info: any = {
                full_range: data.full_range,
                level: data.level,
            }
            ext_info = DataCURD.filter_null(ext_info);
            staff.ext_info = {
                ...staff.ext_info,
                ...ext_info
            }
            if (data.role_id) {
                await AcsUserRole.upsert({
                    user_id: data.id,
                    role_id: data.role_id
                }, {transaction: t, returning: false})
            }

            await staff.save({transaction: t});
            if (data.domain_id !== undefined) {
                await AcsUserDomain.update({domain_id: data.domain_id}, {where: {user_id: data.id}, transaction: t, returning: []});
            }

            await t.commit();
            resolve({id: data.id});
        } catch (e) {
            await t.rollback();
            reject(e);
        }
    })
}


const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "name": {
                        "type": "string",
                        "title": "客户名称"
                    },
                    "id": {
                        "type": "string",
                        "title": "员工 id"
                    },
                    "email": {
                        "type": "string",
                        "title": "邮箱号"
                    },
                    "memo": {
                        "type": "string",
                        "title": "备注"
                    },
                    "domain_id": {
                        "type": "integer",
                        "title": "部门id"
                    },
                    "status": {
                        "type": "integer",
                        "title": "状态",
                        "description": "0=锁定，1=正常"
                    },
                    "pass": {
                        "type": "string",
                        "title": "密码",
                        "description": "md5 32"
                    },
                    "full_range": {
                        "type": "boolean",
                        "description": "默认为false，false时，只能访问身为项目组成员的项目，否则可以访问公司内部的所有项目",
                        "title": "是否可访问所有项目"
                    },
                    "level": {
                        "type": "integer",
                        "title": "级别"
                    },
                    "role_id": {
                        "type": "string",
                        "title": "角色id"
                    }
                },
                "x-apifox-orders": [
                    "id",
                    "name",
                    "email",
                    "memo",
                    "domain_id",
                    "status",
                    "pass",
                    "full_range",
                    "level",
                    "role_id"
                ],
                "required": [
                    "id"
                ],
                "anyOf": [
                    {
                        "required": [
                            "name"
                        ]
                    },
                    {
                        "required": [
                            "email"
                        ]
                    },
                    {
                        "required": [
                            "memo"
                        ]
                    },
                    {
                        "required": [
                            "domain_id"
                        ]
                    },
                    {
                        "required": [
                            "pass"
                        ]
                    },
                    {
                        "required": [
                            "status"
                        ]
                    },
                    {
                        "required": [
                            "full_range"
                        ]
                    },
                    {
                        "required": [
                            "level"
                        ]
                    },
                    {
                        "required": [
                            "role_id"
                        ]
                    }
                ],
                "title": "请求参数内容"
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "examples": [
                    "1.0"
                ],
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。",
                "examples": [
                    "f2741721-1c07-430e-9f01-5529692340f9"
                ]
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理",
                "default": null
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: modify,
    method_params: {
    },
    guards: []
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
