import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {QueryTypes, WhereOptions} from "sequelize";
import {PrjInfo} from "@core-models/PrjInfo";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import DataCURD from "@core/DataCURD";
import {BizContractInfo} from "@core-models/BizContractInfo";
import {BizCustomer} from "@core-models/BizCustomer";

interface IData {
    /**
     * 合同id
     */
    id: string;
}


function detail(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let data = <IData>json.data;
            let contracts = await BizContractInfo.sequelize!.query(`
                select contract.id , contract.name,
                    contract.handler_id, handler.name as handler_name, 
                    contract.customer_id, customer.name as customer_name,
                    contract.comment, contract.payments,
                    cast(contract.amount as float),
                    contract.doc_id, contract.doc_name, contract.doc_uploaded,
                    contract.pdf_id, contract.pdf_name, contract.pdf_uploaded,
                    contract.prj_id, prj.name as prj_name,
                    contract.creator_id, creator.name as creator_name,
    
                    TO_CHAR(contract.begin_at, 'yyyy-MM-dd') as begin_at,
                    TO_CHAR(contract.end_at, 'yyyy-MM-dd') as end_at,
                    TO_CHAR(contract.updated_at, 'yyyy-MM-dd HH24' || ':' || 'MI' || ':' || 'ss') as updated_at,
                    TO_CHAR(contract.created_at, 'yyyy-MM-dd HH24' || ':' || 'MI' || ':' || 'ss') as created_at,
                    TO_CHAR(contract.signed_at, 'yyyy-MM-dd') as signed_at
                from ${BizContractInfo.table_name} contract
                left join ${PrjInfo.table_name} prj on prj.id = contract.prj_id
                left join ${BizCustomer.table_name} customer on contract.customer_id = customer.id
                left join ${AcsUserInfo.table_name} handler on handler.id = contract.handler_id
                left join ${AcsUserInfo.table_name} creator on creator.id = contract.creator_id
                where contract.id = :contract_id 
            `, {type: QueryTypes.SELECT, raw: true, replacements: {
                    contract_id: data.id
                }})
            if(!contracts) return reject(Resp.gen_err(Resp.ResourceNotFound));
            resolve(DataCURD.filter_null(contracts[0]));
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "id": {
                        "type": "string",
                        "title": "合同id"
                    }
                },
                "x-apifox-orders": [
                    "id"
                ],
                "title": "请求参数内容",
                "required": [
                    "id"
                ]
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: detail,
    method_params: {},
    guards: []
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
