import {ADMINISTRATOR, IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {BizContractInfo} from "@core-models/BizContractInfo";
import {PrjInfo} from "@core-models/PrjInfo";

interface IData {
    /**
     * 合同id
     */
    id: string;
}

async function remove(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    let data = <IData>json.data;
    let t = await BizContractInfo.sequelize!.transaction();
    try {
        await PrjInfo.update({contract_id: null}, {where: {contract_id: data.id}, returning: false, transaction: t});
        await BizContractInfo.destroy({where: {id: data.id}, transaction: t});
        await t.commit();
    } catch (e) {
        await t.rollback();
        throw Resp.throw_err(e);
    }
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "id": {
                        "type": "string",
                        "title": "合同id"
                    }
                },
                "x-apifox-orders": [
                    "id"
                ],
                "title": "请求参数内容",
                "required": [
                    "id"
                ]
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: remove,
    method_params: {},
    guards: []
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
