import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {Op, QueryTypes, WhereOptions} from "sequelize";
import DataCURD from "@core/DataCURD";
import {BizCustomer} from "@core-models/BizCustomer";
import {BizCustomerLevel} from "@core-models/BizCustomerLevel";
import {IStatInfo} from "@src/utils/define";
import {PrjInfo} from "@core-models/PrjInfo";
import {BizContractInfo} from "@core-models/BizContractInfo";
import {string_to_number_trim_zeros} from "@src/utils/number_helper";

function stat(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let result = new Array<IStatInfo>;
            /// 获取合同总数
            let count = await BizContractInfo.count({});
            result.push({
                name: '总合同数',
                value: count,
                unit: '个'
            })
            /// 获取合同总金额
            let amount: any = await BizContractInfo.sequelize!.query(
                `SELECT SUM(amount) as amount FROM ${BizContractInfo.table_name}`,
                {type: QueryTypes.SELECT});
            result.push({
                name: '当年累计',
                value: string_to_number_trim_zeros(amount[0].amount),
                unit: '万元'
            })
            /// 获取本年度合同总数
            let year_count = await BizContractInfo.count({
                where: {
                    created_at: {
                        [Op.gte]: new Date(new Date().getFullYear() + '-01-01 00:00:00'),
                        [Op.lte]: new Date(new Date().getFullYear() + '-12-31 23:59:59')
                    }
                }
            });
            result.push({
                name: '本年度',
                value: year_count,
                unit: '个'
            });
            /// 获取本年度合同总金额
            let year_amount: any = await BizContractInfo.sequelize!.query(
                `SELECT SUM(amount) as amount 
                    FROM ${BizContractInfo.table_name} 
                    WHERE created_at >= '${new Date(new Date().getFullYear() + '-01-01 00:00:00').toISOString()}' 
                        AND created_at <= '${new Date(new Date().getFullYear() + '-12-31 23:59:59').toISOString()}'`,
                {type: QueryTypes.SELECT}
            );
            result.push({
                name: '本年度累计',
                value: string_to_number_trim_zeros(year_amount[0].amount),
                unit: '万元'
            });
            resolve({list: result});
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {},
                "x-apifox-orders": [],
                "title": "请求参数内容"
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "examples": [
                    "1.0"
                ]
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理",
                "title": "UTC时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "sign",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: stat,
    method_params: {},
    guards: []
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
