import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {Oss} from "@util/Oss";
import {PrjFile} from "@core-models/PrjFile";

interface IData {
    id: string;
}

// TODO: 部分文档不允许删除，或删除时需要与其它信息同步

function remove(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise(async (resolve, reject) => {
        try {
            let data = <IData>json.data;
            let file = await PrjFile.findOne({where: {id: data.id}, raw: true});
            if (!file) throw Resp.gen_err(Resp.ResourceNotFound, `文档（id：${data.id}）不存在。`);
            await PrjFile.destroy({where: {id: data.id}});
            let object_name = file.id;
            let oss = Oss.get_instance('pmr-doc');
            await oss.remove_object(oss.bucket, object_name);
            resolve({});
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    });
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "id": {
                        "type": "string",
                        "title": "附件id"
                    }
                },
                "x-apifox-orders": [
                    "id"
                ],
                "title": "请求参数内容",
                "required": [
                    "id"
                ]
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: remove,
    method_params: {},
    guards: []
};

module.exports = {
    default: v1_0,
    v1_0: v1_0
};
