import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {PrjInfo} from "@core-models/PrjInfo";

interface IData  {
    /**
     * 项目id
     */
    id: string;
}



function get_checkers(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let data = <IData>json.data;
            let prj = await PrjInfo.findOne({
                where: {
                    id: data.id
                }
            })
            if(!prj) return reject(Resp.gen_err(Resp.ResourceNotFound));
            resolve({
                checkers: prj.checkers
            });
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "id": {
                        "type": "string",
                        "title": "项目id"
                    }
                },
                "x-apifox-orders": [
                    "id"
                ],
                "required": [
                    "id"
                ],
                "title": "请求参数内容"
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "examples": [
                    "1.0"
                ],
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。",
                "examples": [
                    "f2741721-1c07-430e-9f01-5529692340f9"
                ]
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理",
                "default": null
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: get_checkers,
    method_params: {},
    guards: []
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
