import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {QueryTypes, WhereOptions} from "sequelize";
import DataCURD, {ISQLReplacements} from "@core/DataCURD";
import {AcsUserInfo} from "@core-models/AcsUserInfo";
import {PrjMembers} from "@core-models/PrjMembers";
import {AcsRole} from "@core-models/AcsRole";

interface IData {
    /**
     * 项目id
     */
    prj_id: string;
    [property: string]: any;
}


function get_list(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let data = <IData>json.data;
            let sql = `
                select member.member_id as account_id, userinfo.name as name,
                       member.role_id, role.name as role_name,
                       member.memo
                from ${PrjMembers.table_name} member
                left join ${AcsUserInfo.table_name} userinfo on member.member_id = userinfo.id 
                left join ${AcsRole.table_name} role on member.role_id = role.id
                where prj_id = :prj_id and draft = false
            `
            let replacements: ISQLReplacements = {prj_id: data.prj_id};
            let result = await PrjMembers.sequelize!.query(sql, {type: QueryTypes.SELECT, replacements: replacements, raw: true});
            let list = DataCURD.filter_null(result);
            resolve({list: list});
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "prj_id": {
                        "type": "string",
                        "title": "项目id"
                    }
                },
                "title": "请求参数内容",
                "required": [
                    "prj_id"
                ]
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: get_list,
    method_params: {}
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
