import {ADMINISTRATOR, IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {PrjInfo} from "@core-models/PrjInfo";
import {PrjMembers} from "@core-models/PrjMembers";
import {Resp} from "@util/Resp";
import {PrjPhaseDefine} from "@core-models/PrjPhaseDefine";
import {PrjPlanTask} from "@core-models/PrjPlanTask";

interface IData {
    /**
     * 任务id
     */
    task_id: string;
    [property: string]: any;
}

// TODO: 计算进度时要过滤已废除的
async function cancel_task(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    let data = <IData>json.data;
    try {
        await PrjPlanTask.update({status: 90}, {where: {id: data.task_id}});
    } catch (e) {
        throw Resp.throw_err(e);
    }
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "task_id": {
                        "type": "string",
                        "title": "任务id"
                    }
                },
                "x-apifox-orders": [
                    "task_id"
                ],
                "title": "请求参数内容",
                "required": [
                    "task_id"
                ]
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: cancel_task,
    method_params: {},
    guards: []
}

module.exports = {
    default: v1_0,
    v1_0: v1_0
}
