import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {Oss} from "@util/Oss";
import {BizContractInfo} from "@core-models/BizContractInfo";
import {PrjWeekReport} from "@core-models/PrjWeekReport";
import {PrjFile} from "@core-models/PrjFile";

interface IData {
    /**
     * 周报附件id
     */
    id: string;
}


function remove_file(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise(async (resolve, reject) => {
        let t = await BizContractInfo.sequelize!.transaction();
        try {
            let data = <IData>json.data;
            let file = await PrjFile.findOne({where: {id: data.id, category_id: 'week_report'}, raw: true, transaction: t});
            if (!file) throw Resp.gen_err(Resp.ResourceNotFound, `合同附件（id：${data.id}）不存在。`);
            let prj_id = file.prj_id;
            // TODO: 检查是否是项目组成员或有访问项目的权限

            if (file.uploaded === false) throw Resp.gen_err(Resp.ResourceNotFound, '附件尚未上传。')


            let oss = Oss.get_instance('pmr-doc');
            await oss.remove_object(oss.bucket, file.id);
            await PrjFile.destroy({where: {id: data.id}, transaction: t});
            await t.commit();
            resolve({});
        } catch (e) {
            await t.rollback();
            reject(Resp.throw_err(e));
        }
    });
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "id": {
                        "type": "string",
                        "title": "周报附件id"
                    }
                },
                "x-apifox-orders": [
                    "id"
                ],
                "title": "请求参数内容",
                "required": [
                    "id"
                ]
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: remove_file,
    method_params: {},
    guards: []
};

module.exports = {
    default: v1_0,
    v1_0: v1_0
};
