/// 本人已完成工作项统计信息接口
import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {Op, QueryTypes, WhereOptions} from "sequelize";
import {IStatInfo} from "@src/utils/define";
import {BpmnWork} from "@core-models/BpmnWork";

function stat(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let result = new Array<IStatInfo>;

            /// 获取归属于自己的总工作项中已完成的数量，status=2表示已完成
            let done_count = await BpmnWork.count({
                where: {
                    assigned_to: cached_data.user_id,
                    status: 2
                }
            });
            result.push({
                name: '总数',
                value: done_count,
                unit: '个'
            });

            /// 获取本年度本人已完成的工作项总数
            let this_year_done_count = await BpmnWork.count({
                where: {
                    assigned_to: cached_data.user_id,
                    status: 2,
                    started_at: {
                        [Op.gte]: new Date(new Date().getFullYear() + '-01-01 00:00:00'),
                        [Op.lte]: new Date(new Date().getFullYear() + '-12-31 23:59:59')
                    }
                }
            });
            result.push({
                name: '本年度',
                value: this_year_done_count,
                unit: '个'
            });

            resolve({list: result});
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {},
                "x-apifox-orders": [],
                "title": "请求参数内容"
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "examples": [
                    "1.0"
                ]
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理",
                "title": "UTC时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "sign",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: stat,
    method_params: {},
    guards: []
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
