import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {BpmnWork} from "@core-models/BpmnWork";
import {FlowEngine} from "@src/bpmn/flow_engine";
import {PrjLogger} from "../../../../utils/prj_logger";

interface IData  {
    /**
     * 表单数据，有表单的工作，在提交工作时需要同时提交表单数据
     */
    form_data?: { [key: string]: any };
    /**
     * 工作id
     */
    id: string;
}


function submit(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<void> {
    return new Promise(async (resolve, reject) => {
        // let t = await BpmnTask.sequelize!.transaction();
        try {
            let data = <IData>json.data;
            let engine = FlowEngine.execution_engine_map.get(data.id);
            if (engine) {
                let work = await BpmnWork.findOne({where: {id: data.id}, raw: true});
                if (work && work.status !== 2) {
                    // if (data.form_data && data.form_data.pass !== undefined) {
                    //     data.form_data.break = !data.form_data.pass;
                    // }
                    await engine.signal(work.activity_id, data.id, cached_data.user_id, {...data.form_data});
                    await PrjLogger.log({
                        creator_id: cached_data.user_id,
                        creator_name: cached_data.user_name,
                        content: work.name,
                        prj_id: work.prj_id,
                        task_id: work.task_id,
                    })
                }

            }
            // await t.commit();
            resolve();
        } catch (e) {
            // await t.rollback();
            reject(Resp.throw_err(e));
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {
                    "id": {
                        "type": "string",
                        "title": "任务id"
                    },
                    "form_data": {
                        "type": "object",
                        "properties": {},
                        "x-apifox-orders": [],
                        "title": "表单数据",
                        "description": "有表单的任务，在提交任务时需要同时提交表单数据"
                    }
                },
                "x-apifox-orders": [
                    "id",
                    "form_data"
                ],
                "title": "请求参数内容",
                "required": [
                    "id"
                ]
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "default": "1.0"
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "title": "UTC时间戳",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: submit,
    method_params: {},
    guards: []
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
