/// 按分类统计数量

import {IApiProcessor, ICachedData, IMethodParams, IRequest} from "@core/Defined";
import {Resp} from "@util/Resp";
import {QueryTypes} from "sequelize";
import DataCURD from "@core/DataCURD";
import {PrjMembers} from "@core-models/PrjMembers";

interface IData {

}

function get_list(json: IRequest, params: IMethodParams, cached_data: ICachedData): Promise<any> {
    return new Promise<any>(async (resolve, reject) => {
        try {
            let data = <IData>json.data;
            let sql = `
                WITH ProjectHours AS (
                    SELECT
                        type_id,
                        started_at,
                        deliver_at,
                        -- 计算工作日数（不包括周六周日）
                        (
                            SELECT COUNT(*) FILTER (WHERE EXTRACT(DOW FROM gs) NOT IN (0, 6))
                            FROM generate_series(started_at, deliver_at, '1 day') gs(day)
                        ) AS work_days
                    FROM
                        tb_prj_info
                ),
                ProjectSummaries AS (
                    SELECT
                        type_id,
                        COUNT(*) AS project_count,
                        SUM(work_days) AS total_work_days
                    FROM
                        ProjectHours
                    GROUP BY
                        type_id
                )
                SELECT
                    type_id,
                    case when pidtype.id = 300 then
                        ptype.name
                        else CONCAT_WS('/', pidtype.name, ptype.name)
                    end
                     as type_name,
                    project_count,
                    total_work_days
                FROM
                    ProjectSummaries, tb_acs_domain pidtype, tb_acs_domain ptype
                WHERE ptype.id = type_id and ptype.pid = pidtype.id;
            `;
            let result = await PrjMembers.sequelize!.query(sql, {type: QueryTypes.SELECT,  raw: true});
            let list = DataCURD.filter_null(result);
            resolve({list: list});
        } catch (e) {
            reject(Resp.throw_err(e));
        }
    })
}

const v1_0: IApiProcessor = {
    schema: {
        "type": "object",
        "properties": {
            "data": {
                "type": "object",
                "properties": {},
                "x-apifox-orders": [],
                "title": "请求参数内容"
            },
            "ver": {
                "type": "string",
                "title": "版本号",
                "description": "文档中没有说明时，默认为1.0",
                "examples": [
                    "1.0"
                ]
            },
            "app_id": {
                "type": "string",
                "title": "应用id",
                "description": "平台分配给客户端的app id。一个应用一个id。"
            },
            "timestamp": {
                "type": "integer",
                "description": "UTC时间戳，精确到毫秒。平台对超过五分钟的消息，将做忽略处理",
                "title": "UTC时间戳"
            },
            "sign": {
                "type": "string",
                "title": "签名"
            },
            "token": {
                "type": "string",
                "title": "身份认证token",
                "description": "平台登录后分配的token"
            }
        },
        "x-apifox-orders": [
            "ver",
            "app_id",
            "timestamp",
            "token",
            "sign",
            "data"
        ],
        "required": [
            "data",
            "ver",
            "app_id",
            "timestamp",
            "token"
        ]
    },
    method: get_list,
    method_params: {}
}


module.exports = {
    default: v1_0,
    v1_0: v1_0
}
